<?php
/*
 * vim: set tabstop=4 :
 * vim: set number :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('base/model/AdminServices.php');
require_once ('base/model/UserServices.php');
require_once ('base/model/UserFactory.php');
require_once ('base/model/PreferenceFactory.php');
require_once ('base/model/PreferenceServices.php');
/**
 * The admin controller
 *
 * @author Barry Nauta March 2003
 * @package be.nauta.booby.base
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class AdminController extends ItemController
{
	/**
	 * Specific administration services
	 * (additional services, the default are the user services)
	 */
	var $adminServices;

	/**
	 * Default constructor
	 */
	function AdminController ()
	{
		parent::ItemController ();
		$this->operations = new UserServices ();
		$this->itemFactory = new UserFactory ();
		
		$this->adminServices = new AdminServices ();
		
		$this->title = 'Booby - Admin';
		$this->pluginName = 'admin';
		$this->itemName = 'Admin';
	}
	
	function getActions ()
	{
		$dictionary = $this->getDictionary ();
		$actions=array(
			array (
				'name'=> $dictionary['actions'],
				'contents'=>
				array (
					array('href'=>'admin.php?action=addAUser', 'name'=>
					$dictionary['adduser'])
				)
			)
		);
		return $actions;
	}
	
	function activate ()
	{
		$dictionary = $this->getDictionary ();
		switch ($this->getAction ())
		{
			case "deleteUser":
				if ($_SESSION['boobyUsername'] == 'admin')
				{
					$userId = $_GET['userId'];
					$this->operations->deleteUser ($_SESSION['boobyUsername'], $userId);
					//$preferenceOperations->deletePreferences ($_SESSION['boobyUsername'], $userId);
					// todo all other tables must be cleared as well.
					Header ("Location: admin.php");
				}
				else
				{
					// todo make sure that a user can delete its account
					die ("Only the administrator can delete users.");
				}
				break;
			case 'addAUser':
				$this->renderer = 'addUser';
				break;
			case 'addUser':
				$preferenceFactory = new PreferenceFactory ();
				$preferenceOperations = new PreferenceServices ();
				$usersettings=$this->itemFactory->requestToUser ();

				if ($usersettings->password == null)
				{
					die ("You must provide at least a password");
				}
				
				// Add the user
				$this->operations->addUser ($_SESSION['boobyUsername'], $usersettings);
				
				// Get and add the language preferences
				$userPrefs = new Preference 
					(0, $usersettings->loginName, 0, 0, "language", null, 'private', null, null, null, $_POST['language']);
				$preferenceOperations->addItem($usersettings->loginName, $userPrefs);
				
				// Get and add the template preferences
				$userPrefs = new Preference
					(0, $usersettings->loginName, 0, 0, "booby_template", null, 'private', null, null, null, $_POST['template']);
				$preferenceOperations->addItem($usersettings->loginName, $userPrefs);
			
				Header ("Location: admin.php");
				break;
			case 'modify':
				$userSettings = $this->operations->getUserForId($_GET['userId']);
				$preferenceOperations = new PreferenceServices ();
				$this->renderObjects =
					$preferenceOperations->getPreferencesAsArray($userSettings->loginName);
				$this->renderEngine->assign('userSettings', $userSettings);
				$this->renderer = 'modifyPreferences';
				break;
			case 'modifyUser':
				if ($_SESSION['boobyUsername'] == 'test')
				{
					die ("Not allowed for test user");
				}
				$userSettings = $this->itemFactory->requestToUser ();
				$this->operations->modifyUser ($_SESSION['boobyUsername'], $userSettings);
				Header("Location: admin.php");
				break;
			case 'modifyAdminConfigPost':
				$this->adminServices->modifyItem ($_POST['name'], $_POST['value']);
			case 'modifyAdminConfigPre':
				$this->renderEngine->assign ('admin_email', 
					$this->adminServices->getAdminConfig ('admin_email'));
				$this->renderEngine->assign ('allow_account_creation', 
					$this->adminServices->getAdminConfig ('allow_account_creation'));
				$this->renderEngine->assign ('installation_path', 
					$this->adminServices->getAdminConfig ('installation_path'));
				$this->renderer = 'modifyAdminConfig';
				break;
			default:
				$this->renderEngine->assign ('pluginName', $this->pluginName);
				$this->renderer = 'administration';
				$this->renderObjects= $this->operations->getAllUsers ($_SESSION['boobyUsername']);
		}
	}
	
	/**
	 * Display which basically means that the template will be invoked
	 */
	function display ()
	{
		include ('base/config/languages.php');
		include ('base/config/templates.php');
		global $menuItems, $menu;

		$this->renderEngine->assign('pluginName', $this->getTitle ());
		$this->renderEngine->assign('title', $this->getTitle ());
		$this->renderEngine->assign('menuItems', $menuItems);
		$this->renderEngine->assign('menu', $menu);
		$this->renderEngine->assign('dictionary', $this->getDictionary ());

		$this->renderEngine->assign('itemId', $this->getItemId ());
		$this->renderEngine->assign('parentId', $this->getParentId ());

		$this->renderEngine->assign('parameters', 
			$this->getParameters ());
		$this->renderEngine->assign('action', 
			$this->getAction ());
		$this->renderEngine->assign('renderObjects', 
			$this->getRenderObjects ());
		$this->renderEngine->assign('renderActions', 
			$this->getActions ());
		$this->renderEngine->assign ('renderer', $this->getTemplateFile ());
	
		$this->renderEngine->assign ('languages', $languages);
		$this->renderEngine->assign ('templates', $templates);
		if (isset ($_GET['debug']))
		{
			error_reporting(E_ALL);			
			$this->renderEngine->display('templates/'.$this->getTemplate().'/template.tpl.php');
			// todo add more
		}
		else
		{
			error_reporting(E_ERROR);
			@$this->renderEngine->display('templates/'.$this->getTemplate().'/template.tpl.php');
		}
	}

	/**
	 * Returns the filename that will be given to the template for display
	 * @return string the filename of the template file to show.
	 */
	function getTemplateFile ()
	{
		// Allow the template to override a specific file. If this file exist (the file in the
		// template directory), it will be loaded, otherwise the default (in the plugin directory)
		// will be loaded
		$renderer = 'templates/'.$this->getTemplate ().'/'.$this->getRenderer (); 
		if (!(file_exists ($renderer)))
		{
			$renderer = 'base/view/'.$this->getRenderer ();
		}
		return $renderer;
	}

	/**
	 * Retrieves the dictionary file by first tryin the language specific
	 * dictionary file, defaulting to the english version if the language specific file for
	 * the item does not exist and returns the contents as an array
	 * @return array the dictionary
	 */
	function getDictionary ()
	{
		include ('base/lang/dictionary_EN.php');
		if (file_exists ('base/lang/dictionary_'.$_SESSION['language'] . '.php'))
		{
			include ('base/lang/dictionary_'.$_SESSION['language'] . '.php');
		}
		return $dictionary;  
	}
}

/*
if ($_SESSION['boobyUsername'] != 'admin')
{
	die ('The admin page can only be accessed by the administrator!');
}
$controller = new AdminController ();
$controller -> activate ();
$controller -> display ();
*/
?>

