<?php
/*
 * vim: set tabstop=4 :
 * vim: set number :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
@session_start ();
include ('base/checkLogin.php');
include_once ('base/config/preferenceConfiguration.php');
include ('menuItems.php');
include ('ext/Savant-1.4.1/Savant.php');
include_once ('base/util/globalFunctions.php');// added by Michael
/**
 * The Controller (abstract base class)
 *
 * @author Barry Nauta
 * @date July 2003 
 * @class 
 * @package be.nauta.booby.base
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class Controller
{
	/**
	 * Specific preferences which can contain user definable parameters
	 * @protected
	 * @variable array preferences
	 */
	var $preferences;

	/**
	 * The template engine
	 * @private
	 * @variable object renderEngine
	 */
	var $renderEngine;

	/**
	 * The current action that is being processed
	 * @variable string action
	 */
	var $action;

	/**
	 * Parameters, placeholder for almost anything
	 * @variable hashtable parameters
	 */
	var $parameters;

	/**
	 * The operations class
	 * @see Operations
	 * @variable object operations
	 */
	var $operations;

	/**
	 * The name of the renderer that will be used for processing
	 * @variable string renderer
	 */
	var $renderer;

	/**
	 * The objects that are the result of the action. The renderer 
	 * typically renders these objects
	 *
	 * @variable array renderObjects
	 */
	//var $renderObjects;

	/**
	 * This name will be used for file lookup and equals the name of 
	 * the subdirectory of the item under the plugins directory
	 *
	 * @variable string pluginName the name of the plugin that is 
	 * controlled
	 */
	var $pluginName;
	
	/**
	 * The name of the item that is controller by this controller. 
	 * This name will be used to retrieve the appropriate view. 
	 * For instance if the itemName is 'Bookmark' and the current
	 * action is 'add', the file 'addBookmark.tpl.php' might be 
	 * resolved.
	 *
	 * @variable string itemName the name of the item that is 
	 * controlled by this controller
	 */
	var $itemName;
	
	/**
	 * The title to display in the browser title bar
	 * @variable string title the title of the current plugin 
	 * (usually preceded by 'Booby - ')
	 */
	var $title;
	
	/**
	 * The object responsable for access rights
	 * @variable RightsManager rightsManager the rightsManager object 
	 * used
	 */
	var $rightsManager;	
	
	/**
	 * The navigation Mode : can be "private" (only items owned by the 
	 * visitor are shown) or "public" (all public items are shown). 
	 * @variable string navigationMode
	 */
	//var $navigationMode;	
	
	/**
	 * The name used for this specific expansion parameters
	 * @variable string expandName
	 */
	//var $expandName;	
	
	/**
	 * Constructor. Fetches the action, the itemId and the parentId from
	 * the request and assigns these parameters to the controller
	 */
	function Controller ()
	{
		$this->parameters = array ();
 		// Fetch the action parameter from the request
		if (isset ($_GET['action']))
		{
			$this->action = $_GET['action'];
		}
		else if (isset ($_POST['action']))
		{
			$this->action = $_POST['action'];
		}
		$this->renderEngine =& new Savant ();
	}
	
	
	/**
	 * Returns the specific URL for this Controller
	 *
	 * @return string URL of this controller
	 */
	function getURL ()
	{
		return $this->getItemName () . "Controller.php";
	}

	/**
	 * Returns the template that is currently in use
	 *
	 * @return string the template that is currently in use
	 */
	function getTemplate ()
	{
		return $_SESSION['booby_template'];
	}

	/**
	 * Returns the name of the renderer that will be used
	 * for further processing
	 *
	 * @return string the renderer
	 */
	function getRenderer ()
	{
		return $this->renderer.'.tpl.php';
	}

	/**
	 * Returns the renderobjects that will be displayed
	 *
	 * @return array the render objects
	 */
	function getRenderObjects ()
	{
		return $this->renderObjects;
	}

	/**
	 * Sets the action that is requested by the user
	 *
	 * @param string theAction the requested action
	 */
	function setAction ($theAction)
	{
		$this->action = $theAction;
	}

	/**
	 * Returns the action that is requested by the user
	 *
	 * @return string theAction the requested action
	 */
	function getAction ()
	{
		return $this->action;
	}

	/**
  	 * Returns the actions defined for this item only
	 * Abstract function.
 	 *
 	 * @return array an array of item specific actions (like search, 
	 * import etc.)
 	 */
	function getActions ()
	{
		return null;
	}

	/**
	 * Add a parameter to the existing parameter hashTable
	 *
	 * @param string key the key for the parameter
	 * @param string value the value of the parameter
	 */
	function addParameter ($key, $value)
	{
		$this->parameters [$key] = $value;
	}

	/**
	 * Retrieves the dictionary file by first tryin the language 
	 * specific dictionary file, defaulting to the english version 
	 * if the language specific file for the item does not exist and 
	 * returns the contents as an array
	 *
	 * @return array the dictionary
	 */
	function getDictionary ()
	{
		// First load the english BASE dictionary file. 
		// This file MUST exist
		include ('base/lang/dictionary_EN.php');
		// If a language specific BASE dictionary exist, 
		// load this one as well.
		if (file_exists ('base/lang/dictionary_'.
			$_SESSION['language'] . '.php'))
		{
			include ('base/lang/dictionary_'.
				$_SESSION['language'] . '.php');
		}
		
		// Now load the english PLUGIN dictionary. 
		// This file MUST exist as well.
		include ('plugins/'.$this->pluginName.'/lang/dictionary_EN.php');
		// If a language specific PLUGIN dictionary exist, 
		// load this one as well.
		if (file_exists ('plugins/'.$this->pluginName.
			'/lang/dictionary_'.$_SESSION['language'] . '.php'))
		{
			include ('plugins/'.$this->pluginName.'/lang/dictionary_'.
				$_SESSION['language'] . '.php');
		}
		// Ok, we're done
		return $dictionary;  
	}
	
	/**
	 * Returns the filename that will be given to the template for 
	 * display
	 *
	 * @return string the filename of the template file to show.
	 */
	function getTemplateFile ()
	{
		// Allow the template to override a specific file. 
		// If this file exist (the file in the
		// template directory), it will be loaded, otherwise the 
		// default (in the plugin directory) will be loaded
		$renderer = 'templates/'.$this->getTemplate ().'/'.
			$this->getRenderer (); 
		if (!(file_exists ($renderer)))
		{
			$renderer = 'plugins/' . $this->pluginName.'/view/'.
				$this->getRenderer ();
		}
		return $renderer;
	}
	
	/**
	 * Display which basically means that the template will be invoked
	 */
	function display ()
	{
		include('menuItems.php');
		//global $menuItems, 
		global $menu;

		$this->renderEngine->assign('title', $this->getTitle ());
		$this->renderEngine->assign('menuItems', $menuItems);
		$this->renderEngine->assign('menu', $menu);
		$this->renderEngine->assign('dictionary', 
			$this->getDictionary ());

		$this->renderEngine->assign('parameters', 
			$this->getParameters ());
		$this->renderEngine->assign('action', 
			$this->getAction ());
		$this->renderEngine->assign('renderObjects', 
			$this->getRenderObjects ());
		$this->renderEngine->assign('renderActions', 
			$this->getActions ());
			
		$this->renderEngine->assign ('pluginName', $this->pluginName);
		$this->renderEngine->assign ('renderer', 
			$this->getTemplateFile ());
		if (isset ($_GET['debug']))
		{
			error_reporting(E_ALL);			
			$this->renderEngine->display('templates/'.
				$this->getTemplate().'/template.tpl.php');
			// todo add more
		}
		else
		{
			error_reporting(E_ERROR);
			@$this->renderEngine->display('templates/'.
				$this->getTemplate().'/template.tpl.php');
		}
	}


	/**
	 * Returns this controllers parameters
	 *
	 * @return hashtable the parameters (key/value based)
	 */
	function getParameters ()
	{
		return $this->parameters;
	}

	/**
	 * Returns the title of this Controller
	 *
	 * @return string the title of this controller
	 */
	function getTitle ()
	{
		return $this->title;
	}

	/**
	 * Returns the name of the item that is controller by this 
	 * controller
	 *
	 * @return string the name of the item that is controlled by this 
	 * controller
	 */
	function getItemName ()
	{
		return $this->itemName;
	}

	/**
	 * Returns the name of the plugin that is controlled by this 
	 * controller. This name will be used for file lookup and equals 
	 * the name of the subdirectory of the item under the plugins 
	 * directory
	 *
	 * @return string the name of the plugin that is controlled by this 
	 * controller
	 */
	function getPluginName ()
	{
		return $this->pluginName;
	}

	function getUserName ()
	{
		return $_SESSION['boobyUsername'];
	}

	function getDashboard ()
	{
		return null;
	}
}
?>
