<?php
/**
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/Controller.php');
require_once ('base/model/PluginServices.php');

/**
 * The Dashboard controller: shows info per activated plugin
 * on the index page
 *
 * @package be.nauta.booby.base
 * @author Barry Nauta July 2004
 *
 * @copyright
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 */
class DashboardController extends Controller
{
	/**
	 * Theplugin services, used to ask for the activated 
	 * plugins for the current user
	 */
	var $pluginServices;

	/**
	 * Default constructor
	 */
	function DashboardController ()
	{
		parent::Controller ();
		$this->title = 'Booby';
		$this->pluginName = 'dashboard';
		$this->itemName = 'Dashboard';

		$this->pluginServices = new PluginServices ();
	}

	/**
	 * Activates the controller
	 */
	function activate ()
	{
		$dictionary = $this->getDictionary ();
		$this->renderer = 'index';
		$this->renderObjects = sprintf ($dictionary['welcome_page'], $this->getUserName());
		$this->renderEngine->assign ('dashboard', $this->getDashboard());
		include ('base/config/languages.php');
		$this->renderEngine->assign('languages', $languages);
	}

	/** 
	 * Loop over all activated plugins and retrieve dashboard (overview)
	 * information for the specific plugin
	 *
	 * @return array an array with dashboard iformation per plugin
	 */
	function getDashboard ()
	{
		include ('base/config/plugins.php');
		$result = array ();
		$configuredPlugins = 
			$this->pluginServices->getPluginSettingsAsArray 
				($this->getUserName());

		foreach ($plugins as $plugin)
		{
				$name = $plugin['name'];
				// Weird....=='true'
				if ($configuredPlugins[$name] == 'true')
				{
					include ('plugins/'.$name.'/'.$plugin['controller']);
					$controller = new $plugin['controllerName'];
					$contents = $controller->getDashboard ($plugin['dashboardContent'], 5, $plugin['dashboardSort']);
					if (isset ($plugin['dashboardAction']))
					{
						$result[$name]= array (
							'name'=>$name,
							'content'=>$plugin['dashboardContent'],
							'contents'=>$contents,
							'action'=>$plugin['dashboardAction'],
							'title'=>$plugin['dashboardTitle'],
							'controller'=>$plugin['controller']
					);
					}
				}
		}	
		return $result;
	}
	
	/**
	 * Returns the filename that will be given to the template for 
	 * display
	 * @return string the filename of the template file to show.
	 */
	function getTemplateFile ()
	{
		// Allow the template to override a specific file. 
		// If this file exist (the file in the template directory), 
		// it will be loaded, otherwise the default (in the plugin 
		// directory) will be loaded
		$renderer = 'templates/'.$this->getTemplate ().'/'.$this->getRenderer (); 
		if (!(file_exists ($renderer)))
		{
			$renderer = 'base/view/'.$this->getRenderer ();
		}
		return $renderer;
	}

	/**
	 * Retrieves the dictionary file by first tryin the language 
	 * specific dictionary file, defaulting to the english version if 
	 * the language specific file for the item does not exist and 
	 * returns the contents as an array
	 *
	 * @return array the dictionary
	 */
	function getDictionary ()
	{
		include ('base/lang/dictionary_EN.php');
		if (file_exists ('base/lang/dictionary_'.$_SESSION['language'] . '.php'))
		{
			include ('base/lang/dictionary_'.$_SESSION['language'] . '.php');
		}
		// Overrule the title for this page
		$dictionary['title']='Index';
		return $dictionary;  
	}	
}
//$controller = new IndexController ();
//$controller -> activate ();
//$controller -> display ();
?>

