<?php
/*
 * vim: set tabstop=4 :
 * vim: set number :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('base/model/PluginSetting.php');
require_once ('base/model/PluginSettingFactory.php');
require_once ('base/model/PluginServices.php');

//require_once ('base/model/UserServices.php');
//require_once ('base/model/User.php');

require_class ('RightsManagerImpl', 'base/RightsManagerImpl.php'); // added by Michael
require_class ('RequestCast', 'base/util/request/RequestCast.class.php'); // added by Michael

/**
 * The Plugin Controller
 *
 * @author Barry Nauta
 * @date July 2004
 * @package be.nauta.booby.base
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class PluginController extends ItemController
{
	/**
	 * Constructor. 
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function PluginController ()
	{
		parent::ItemController ();
		$this->operations = new PluginServices ();
		$this->itemFactory = new PluginSettingFactory ();
		
		$this->rightsManager = new RightsManagerImpl(); 

		$this->pluginName = 'plugin';
		$this->title = 'Booby - Plugin Settings';
		$this->itemName = 'PluginSetting';
	}

	/**
	 * Activate. Basically this means that the appropriate actions 
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		include ('base/config/languages.php');
		include ('base/config/templates.php');
		$this->renderEngine->assign ('languages', $languages);
		$this->renderEngine->assign ('templates', $templates);

		switch ($this->getAction ())
		{
			case 'modifyPluginSetting':
				$setting = $this->itemFactory->requestToItem ();
				//die (print_r ($setting));
				$currentValue = $this->operations->getPluginSettingValue
					($this->getUserName(), $setting->name);
				if (!isset ($currentValue))
				{
					$this->operations->addItem 
						($this->getUserName (), $setting);
				}
				else
				{
					$setting->itemId = $this->operations->getPluginSettingId 
						($setting->owner, $setting->name);
					$this->operations->modifyItem 
						($this->getUserName(), $setting);
				}
				include ('menuItems.php');
				$this->renderEngine->assign ('menuItems', $menuItems);
				//$this->getShowItemsParameters ();
				//break;
			default:
				$plugins = $this->operations->getPlugins ();
			 	$this->renderEngine->assign
					('plugins', $plugins);
				$this->renderObjects =
					$this->operations->getPluginSettingsAsArray
						($this->getUserName());
				$this->renderer = 'modifyPluginSettings';
				break;
		}
	}
	
	/**
	 * Returns the filename that will be given to the template for 
	 * display
	 * @return string the filename of the template file to show.
	 */
	function getTemplateFile ()
	{
		// Allow the template to override a specific file. 
		// If this file exist (the file in the template directory), 
		// it will be loaded, otherwise the default 
		// (in the plugin directory) will be loaded
		$renderer = 'templates/'.$this->getTemplate ().'/'.
			$this->getRenderer (); 
		if (!(file_exists ($renderer)))
		{
			$renderer = 'base/view/'.$this->getRenderer ();
		}
		return $renderer;
	}
	
	/**
	 * Retrieves the dictionary file by first tryin the language 
	 * specific dictionary file, defaulting to the english version 
	 * if the language specific file for
	 * the item does not exist and returns the contents as an array
	 * @return array the dictionary
	 */
	function getDictionary ()
	{
		include ('base/lang/dictionary_EN.php');
		if (file_exists ('base/lang/dictionary_'.$_SESSION['language'] . '.php'))
		{
			include ('base/lang/dictionary_'.$_SESSION['language'] . '.php');
		}
		return $dictionary;  
	}
	
	
}
//$controller = new PluginController ();
//$controller -> activate ();
//$controller -> display ();
?>
