<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('base/model/Preference.php');
require_once ('base/model/PreferenceFactory.php');
require_once ('base/model/PreferenceServices.php');

require_once ('base/model/UserServices.php');
require_once ('base/model/User.php');

require_class ('RightsManagerImpl', 'base/RightsManagerImpl.php'); // added by Michael
require_class ('RequestCast', 'base/util/request/RequestCast.class.php'); // added by Michael

/**
 * The Preference Controller
 *
 * @author Barry Nauta
 * @date January 2004
 * @package be.nauta.booby.base
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class PreferenceController extends ItemController
{
	/**
	 * Constructor. 
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function PreferenceController ()
	{
		parent::ItemController ();
		$this->operations = new PreferenceServices ();
		$this->itemFactory = new PreferenceFactory ();
		
		$this->rightsManager = new RightsManagerImpl(); 

		$this->pluginName = 'user';
		$this->title = 'Booby - Preferences';
		$this->itemName = 'Preferences';
	}

	/**
	 * Activate. Basically this means that the appropriate actions are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		include ('base/config/languages.php');
		include ('base/config/templates.php');
		$this->renderEngine->assign ('languages', $languages);
		$this->renderEngine->assign ('templates', $templates);

		switch ($this->getAction ())
		{
			case 'modifyPreferences':
				$preference = $this->itemFactory->requestToItem ();
				$preference->itemId = $this->operations->getPreferenceId 
						($preference->owner, $preference->name);
				$this->operations->modifyItem ($this->getUserName(), $preference);
				
				// All preferences are placed on the session if we have changed our own preferences
				// (admin can change other preferences as well)
				if ($this->getUserName()==$preference->owner)
				{
					$_SESSION[$preference->name]=$preference->value;
				}
				$this->getShowItemsParameters ();
				Header ("Location: index.php");
				break;
			default:
				$userServices = new UserServices ();
				$userSettings= $userServices->getUser
					($this->getUserName(),$this->getUserName());
				$this->modifyAction ();
				$this->renderEngine->assign('userSettings', $userSettings);		
				$this->renderObjects =
					$this->operations->getPreferencesAsArray($this->getUserName());
				$this->renderer = 'modifyPreferences';
				break;
		}
	}
	
	/**
	 * Returns the filename that will be given to the template for display
	 * @return string the filename of the template file to show.
	 */
	function getTemplateFile ()
	{
		// Allow the template to override a specific file. If this file exist (the file in the
		// template directory), it will be loaded, otherwise the default (in the plugin directory)
		// will be loaded
		$renderer = 'templates/'.$this->getTemplate ().'/'.$this->getRenderer (); 
		if (!(file_exists ($renderer)))
		{
			$renderer = 'base/view/'.$this->getRenderer ();
		}
		return $renderer;
	}
	
	/**
	 * Retrieves the dictionary file by first tryin the language specific
	 * dictionary file, defaulting to the english version if the language specific file for
	 * the item does not exist and returns the contents as an array
	 * @return array the dictionary
	 */
	function getDictionary ()
	{
		include ('base/lang/dictionary_EN.php');
		if (file_exists ('base/lang/dictionary_'.$_SESSION['language'] . '.php'))
		{
			include ('base/lang/dictionary_'.$_SESSION['language'] . '.php');
		}
		return $dictionary;  
	}
	
	
}
//$controller = new PreferenceController ();
//$controller -> activate ();
//$controller -> display ();
?>
