<?php
/*
 * vim: set number : 
 * vim: set tabstop=4 : 
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/model/PluginSetting.php');
require_once ('base/model/PluginSettingFactory.php');
require_once ('base/model/Services.php');
/**
 * Operations on plugin settings
 *
 * @author Barry Nauta July 2004
 * @package be.nauta.booby.base.model
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta 
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>  
 * and look for licenses
 */
class PluginServices extends Services
{
	/**
 	 * Default constructor
	 */
	function PluginServices ()
	{
		parent::Services();
		$this->itemFactory = new PluginSettingFactory ();

		include ('base/sql/pluginQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds a plugin setting for a user
	 * 
	 * @param integer userId the identifier for the user
	 * @param object item the item to be added
	 */
	function addItem ($userId, $item)
	{
			/*
        if ($this->getUserName() != $userId) 
        { 
        	if ($this->getUserName()!='admin')
        	{
        		return null;
        	} 
        }
		*/

        global $db;
		$now = date ("Y-m-d H:i:s");
		$query  = sprintf ($this->queries['addItem'],
			$userId, 
			$item->parentId, 
			$item->isParent, 
			addslashes ($item->name),
			addslashes ($item->description),
			$item->visibility,
			$item->category, 
			$now, 
			$item->value);
		$result = $db->Execute($query) 
			or die("AddPluginSetting: " . $db->ErrorMsg() . " " . $query);
	}

	/**
	 * Modifies a plugin setting.
	 *
 	 * @param integer userId the identifier for the user who 
	 * modifies a setting
	 * @param object item the modified setting
	 */
	function modifyItem ($userId, $item)
	{
        global $db;
		$now = date ("Y-m-d H:i:s");
		$query  = sprintf ($this->queries['modifyItem'], 
			$now, 
			addslashes ($item->name),
			addslashes ($item->description), 
			$item->parentId, 
			$item->value, 
			$item->itemId) ;
			//die ($query);
		$result = $db->Execute($query) 
			or die("ModifyPluginSetting: " . $db->ErrorMsg() . " " . $query);
	}
	
	/**
	 * Returns all plugins of a specific user in an array
	 * @param integer userId the identifier of the user for which we 
	 * would like to have the preferences
	 * @return array an array of all the preferences of this user
	 */
	function getPluginSettingsAsArray ($userId)
	{
		$result = array ();
		$settings = parent::getItems ($userId);
		if ($settings != null)
		{
			foreach ($settings as $setting)
			{
				$result [$setting->name]=$setting->value;
			}
		}
		$result['owner']=$userId;
		return $result;
	}
	
	/**
	 * Returns the id of a specific setting (lookup on the name of the 
	 * setting, not the object!) for a specific user
	 * @param integer userId the identifier of the user
	 * @param string name the name of the setting for which we would 
	 * like to know its identifier
	 * @return integer the identifier of the setting for the specific 
	 * user
	 */
	function getPluginSettingId ($userId, $name)
	{
		global $db; 
		
		$query = sprintf ($this->queries ['getPluginSettingId'], 
			$userId, $name);
		$result = $db->Execute($query) 
			or die("GetPluginSettingId: " . $db->ErrorMsg() . " " . $query);
		return $result->fields[0];
	}
	
	/**
	 * Gets the pluginsetting-value for a specific user
	 * @param integer userId the identifier of the user
	 * @param string name the name of the setting for which we would 
	 * like to  know its value
	 * @return string the value of the setting for the specific user
	 */
	function getPluginSettingValue ($userId, $name)
	{
		global $db; 
		
		$query = sprintf ($this->queries ['getPluginSetting'], 
			$userId, $name);
		$result = $db->Execute($query) 
			or die("GetPluginSetting: " . $db->ErrorMsg() . " " . $query);
		return $result->fields[0];
	}

	/**
	 * Sets a pluginsetting (name/value pair) for a specific user
	 * @param integer userId the identifier of the user
	 * @param string name the name of the setting to set
	 * @param string value the value of the setting to set
	 */ 	
	function setPluginSetting ($userId, $name, $value)
	{
		$setting = $this->getPluginSettingValue ($userId, $name);
		if ($setting == null)
		{
			$setting = $this->itemFactory->getPluginSetting 
				($userId, $name, $value);
			$this->addItem ($userId, $setting);
		}
		else
		{
			$settingId = $this->getPluginSettingId ($userId, $name);
			$setting = $this->getItem ($userId, $settingId);
			$setting->value = $value;
			$this->modifyItem ($userId, $setting);
		}
	}

	/**
	 * @todo fetch from database
	 */
	function getPlugins ()
	{
		include 'base/config/plugins.php';
		/*
		$result = array ('bookmarks', 
						'contacts', 
						'news', 
						'notes',
						'todos',
						'webtools');
						*/
		$result = $plugins;
		return $result;
	}
}
?>
