<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/model/Preference.php');
require_once ('base/model/PreferenceFactory.php');
require_once ('base/model/Services.php');
/**
 * Operations on preferences
 *
 * @author Barry Nauta January 2004
 * @package be.nauta.booby.base.model
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta 
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>  
 * and look for licenses
 */
class PreferenceServices extends Services
{
	/**
 	 * Default constructor
	 */
	function PreferenceServices ()
	{
		parent::Services();
		$this->itemFactory = new PreferenceFactory ();

		include ('base/sql/preferenceQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds preferences for a user
	 * 
	 * @param integer userId the identifier for the user
	 * @param object item the item to be added
	 */
	function addItem ($userId, $item)
	{
        if ($this->getUserName() != $userId) 
        { 
        	if ($this->getUserName()!='admin')
        	{
        		return null;
        	} 
        }

        global $db;
		$now = date ("Y-m-d H:i:s");
		$query  = sprintf ($this->queries['addItem'],
			$userId, 
			$item->parentId, 
			$item->isParent, 
			addslashes ($item->name),
			addslashes ($item->description),
			$item->visibility,
			$item->category, 
			$now, 
			$item->value);
		$result = $db->Execute($query) 
			or die("AddPreferences: " . $db->ErrorMsg() . " " . $query);
	}

	/**
	 * Modifies a preference.
	 *
 	 * @param integer userId the identifier for the user who modifies a preference
	 * @param object item the modified preference
	 */
	function modifyItem ($userId, $item)
	{
		//die ($this->getPreferenceValue ($item->name));
        global $db;
		$now = date ("Y-m-d H:i:s");
		$query  = sprintf ($this->queries['modifyItem'], 
			$now, 
			addslashes ($item->name),
			addslashes ($item->description), 
			$item->parentId, 
			$item->value, 
			$item->itemId) ;
		$result = $db->Execute($query) 
			or die("ModifyPreference: " . $db->ErrorMsg() . " " . $query);
	}
	
	/**
	 * Returns all preferences of a specific user in an array
	 * @param integer userId the identifier of the user for which we would like
	 * to have the preferences
	 * @return array an array of all the preferences of this user
	 */
	function getPreferencesAsArray ($userId)
	{
		$result = array ();
		$preferences = parent::getItems ($userId);
		if ($preferences == null)
		{
			die ("getPreferencesAsArray -> no preferences for user with id-".$userId."-");
		}
		foreach ($preferences as $preference)
		{
			$result [$preference->name]=$preference->value;
		}
		$result['owner']=$userId;
		return $result;
	}
	
	/**
	 * Returns the id of a specific preference (lookup on the name of the preferene, not the 
	 * object!) for a specific user
	 * @param integer userId the identifier of the user
	 * @param string preferenceName the name of the preference for which we would like to 
	 * know its identifier
	 * @return integer the identifier of the preference for the specific user
	 */
	function getPreferenceId ($userId, $preferenceName)
	{
		global $db; 
		
		$query = sprintf ($this->queries ['getPreferenceId'], $userId, $preferenceName);
		$result = $db->Execute($query) 
			or die("GetPreferenceId: " . $db->ErrorMsg() . " " . $query);
		return $result->fields[0];
	}
	
	/**
	 * Gets the preference-value for a specific user
	 * @param integer userId the identifier of the user
	 * @param string preferenceName the name of the preference for which we would like to 
	 * know its value
	 * @return string the value of the preference for the specific user
	 */
	function getPreferenceValue ($userId, $preferenceName)
	{
		global $db; 
		
		$query = sprintf ($this->queries ['getPreference'], $userId, $preferenceName);
		$result = $db->Execute($query) 
			or die("GetPreference: " . $db->ErrorMsg() . " " . $query);
		return $result->fields[0];
	}

	/**
	 * Sets a preferences (name/value pair) for a specific user
	 * @param integer userId the identifier of the user
	 * @param string name the name of the preference to set
	 * @param string value the value of the preference to set
	 */ 	
	function setPreference ($userId, $name, $value)
	{
		$preference = $this->getPreferenceValue ($userId, $name);
		if ($preference == null)
		{
			$preference = $this->itemFactory->getPreference ($userId, $name, $value);
			$this->addItem ($userId, $preference);
		}
		else
		{
			$prefId = $this->getPreferenceId ($userId, $name);
			$pref = $this->getItem ($userId, $prefId);
			$pref->value = $value;
			$this->modifyItem ($userId, $pref);
		}
	}
}
?>
