<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
include ('base/util/databaseConnection.php');
include_once ('base/model/User.php');
include_once ('base/model/UserFactory.php');
/**
 * Operations class for users
 *
 * @author Barry Nauta
 * @date March 2003
 * @package be.nauta.booby.base.model
 * @copyright 
 *
 * Copyright (c) 2003 - 2004Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class UserServices
{
	/**
	 * The queries that are used for database interactions
	 * @variable array queries
	 */
	var $queries;
	
	/**
	 * The factory for user objects
	 * @private
	 * @variable object factory
	 */
	var $factory;
	
	/**
	 * Default constructor
	 */
	function UserServices ()
	{
		$this->factory = new UserFactory ();
		
		include ('base/sql/userQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds a user to the system
	 *
	 * @param string userId the identifier fr the user who issues the request
	 * (should be admin, I guess???)
	 * @param object aUser the user to be added
	 */
	function addUser ($userId, $aUser)
	{
//		if ($this->getUserName() != 'admin') { die ("Not allowed!!!"); }

		global $db;
		$now = date ("Y-m-d H:i:s");

		// First check whether the user which we want to add already exists (check basd 
		// on login name)
		$query = sprintf ($this->queries['getUser'], $aUser->loginName);
		$result = $db->Execute ($query)
			or die ("Add user: " . $db->ErrorMsg () . " " . $query);
		$existingUser = $this->factory->resultSetToUsers ($result);
		if ($existingUser != null)
		{
			die ("User already exists!");
		}		
		
		// If the user does not yet exist, add it
		$query = sprintf ($this->queries['addUser'],
			$aUser->loginName, 
			MD5($aUser->password), 
			$aUser->name, 
			$aUser->email,
			$aUser->description, 
			$now, 
			null);
		$result = $db->Execute ($query)
			or die ("Add user: " . $db->ErrorMsg () . " " . $query);

		// And return the last insert id
		$query = $this->queries['lastUserInsertId'];
		$result = $db->Execute ($query)
			or die ("Add user: " . $db->ErrorMsg () . " " . $query);

		return $result->fields[0];
	}

	/**
 	 * Modifies a users parameters
	 *
	 * @param string userId the requestor
	 * @param object theUser the modified user
	 */
	function modifyUser ($userId, $theUser)
	{
		if ($this->getUserName() != $userId) 
		{ 
			if ($this->getUserName() != 'admin')
			{
				return null; 
			}
		}
		global $db;
		
		$query = sprintf ($this->queries['modifyUser'],
			$theUser->name, 
			MD5($theUser->password),
			$theUser->description, 
			$theUser->email, 
			$theUser->lastLogin, 
			$theUser->loginName);
		
		$db->Execute ($query)
			or die ("Error updating user: " .
			$db->ErrorMsg () . " " . $query);
	}

	/**
	 * Deletes a user from the system
	 *
	 * @param integer userId the identifier fr the user who issues the request
	 * (should be admin, I guess???)
	 * @param integer theUserId the id of user to be deleted
	 */
	function deleteUser ($userId, $theUserId)
	{
		global $db;
		$query = sprintf ($this->queries['deleteUser'], $theUserId);
		$db->Execute ($query)
			or die ("Error deleteing  user: " .
			$db->ErrorMsg () . " " . $query);
	}

	/**
	 * Retrieves all users
	 *
	 * @param integer userId the identifier of the user who issues the request
	 * @return array all users known to the system
	 */
	function getAllUsers ($userId)
	{
		if ($userId != 'admin')
		{
			return;
		}
		global $db;
		$query  = $this->queries['getAllUsers'];
		$result = $db->Execute ($query)
			or die ($db->ErrorMsg (). "GetAllUsers. " . $query);
		return $this->factory->resultsetToUsers ($result);
	}

	/**
	 * Gets a user
	 *
	 * @param integer userId the identifier for the user who issues the request
	 * @param string requestedUser the identification of the user for which
	 * we would like to know the parameters
	 *
	 * @return the requested user parameters
	 */
	function getUser ($userId, $requestedUser)
	{
		global $db;

		$query = sprintf ($this->queries ['getUser'], $requestedUser);
		$result = $db->Execute ($query)
			or die ('Error retrieving userinformation' .
			$db->ErrorMsg() . " " . $query);
		$users = $this->factory->resultsetToUsers ($result);
		return $users[0];
	}

	/**
 	 * Retrieves a user based on its Id
	 *
	 * @param integer userId the identifier for the user
	 * @return object a fully instantiated user object
	 */
	function getUserForId ($userId)
	{
		global $db;

		$query = sprintf ($this->queries ['getUserForId'], $userId);
		$result = $db->Execute ($query)
			or die ('Error retrieving userinformation' .
			$db->ErrorMsg() . " " . $query);
		$users = $this->factory->resultsetToUsers ($result);
		return $users[0];
	}
	
	function getUserName ()
	{
		return $_SESSION['boobyUsername'];
	}
}
?>
