#drop table if exists booby_admin;
#drop table if exists booby_users;
#drop table if exists booby_user_preferences;

###
# BOOBY_ADMIN
# Will contain values like admin email address, installed plugins,
# available plugins, default language, default template etc.
# This table basically contains name/value pairs to enable to add
# new values withou changing the table structure.
###
create table booby_admin
(
	name			char (70) not null,
	value			char (50),
	key (name)
);

###
# BOOBY_USERS. Field lengths are arbitrary
###
create table booby_users
(
        userId                  integer auto_increment not null primary key,
        loginname                char(15) not null,
        password                char(50),
        name                    char(50),
        email                   char(30),
        description             text,
        when_created    DATETIME,
	lastLogin	DATETIME,
        key(userId)
);

###
# BOOBY_USER_PREFERENCES.  This table must directly be created when a user 
# is created and its ID must be the users ID
###
create table booby_user_preferences
(
	itemId			integer auto_increment not null primary key,
	owner			char (70) not null,
	parentId		integer not null,
	isParent		BOOL,
	name			char (70) not null,
	description 		text,
	visibility		char (15),
	category		char (50),
	when_created	DATETIME,
	when_modified	DATETIME,
	value			char (50),
	key (itemId)
);
create index booby_user_preferences_index on booby_user_preferences (owner, parentId);

###
# BOOBY_PLUGIN_SETTINGS.  
###
create table booby_plugin_settings
(
	itemId			integer auto_increment not null primary key,
	owner			char (70) not null,
	parentId		integer not null,
	isParent		BOOL,
	name			char (70) not null,
	description 		text,
	visibility		char (15),
	category		char (50),
	when_created	DATETIME,
	when_modified	DATETIME,
	value			char (50),
	key (itemId)
);
create index booby_plugin_settings_index on booby_plugin_settings (owner, parentId);

#
#
create table booby_access_control_list
(
         theKey 		integer auto_increment not null primary key,
# who owns this item anyway?
	  owner			char (70) not null,
# the item id on which we would like to give access
  	  itemId		integer not null,
# the item type on which we would like to give access (only the combination of key and type is unique)
	  itemType		char (70) not null,
# who would we like to give access 
 	  userId		integer,
# what kind of access do we want to give (combination of read/write/delete) following the *nix filesystem conventions
	  accessRight		integer,
	  key (theKey)
);
create index booby_acl_index on booby_access_control_list (owner, itemId, itemType, userId);


insert into booby_admin set
	name='allow_account_creation',
	value='0';
insert into booby_admin set
	name='installation_path',
	value='http://localhost/booby';
insert into booby_admin set
	name='admin_email',
	value='changeme@somwhere.com';
insert into booby_admin set
	name='booby_version',
	value='0.3.0';

insert into booby_users set
        loginname='admin',
        password=MD5('admin'),
        name='Booby administrator',
        email='barry@nauta.be',
        description='Administrator',
        when_created=NOW();
update booby_users set userId=0 where loginname='admin';

insert into booby_user_preferences set
        owner='admin',
        name="language",
        value="EN";
insert into booby_user_preferences set
        owner='admin',
        name="booby_template",
        value="mylook";

