<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
/**
 * Cette classe permet de vrifier certains critres d'une srie de variables, 
 * en affectant un message d'erreur lorsqu'un problme est rencontr.
 * 
 * Les paramtres vrifis sont
 * - occurence minimum (si > 1, alors on attend un array en entre)
 * - occurence maximum (si > 1, alors on attend un array en entre)
 * - le type (int, string, alpha, digit, mail). 
 * Il est possible d'en dfinir par hritage.
 * 
 * Exemple d'utilisation : on vrifie que le mail est prsent et valide, et que le tlphone
 * est valide, s'il est prsent. Puis les mssages d'erreur sont affichs, spars par un <BR>
 *
 * $val = new var_validator();
 * $val->validate($_GET['email'], 1, 1, "mail", "Merci de vrifier votre adresse Email");
 * $val->validate($_GET['tel'], 0, 1, "digit", "Merci de vrifier le tlphone");
 * if(!$val->ok)
 * 		$val->echo_error_msg("<br/>");
 * 
 * @package be.nauta.booby.base.util.request
 * @author Michael Haussmann review 11/11/2003
 * @copyright Michael Haussmann
 */
class VariableValidator {

	/**
	* @var $error_msg : array de string : messages d'erreur
	* @desc $error_msg : array de string : messages d'erreur
	*/
	var $error_msg;
	
	/**
	* @var $ok : boolean : prsence ou absence d'erreur. (true = pas d'erreur)
	*/
	var $ok;
	
	// membres privs
      var $default_min;
      var $default_max;
      var $default_type;
      var $default_error_msg;

      function VariableValidator(){ // constructor
               settype($this->error_msg, "array");
               $this->ok = TRUE;
      }

      // Cette fonction valide la variable $var
      function validate($var, $min, $max, $type, $error_msg){

               // Si $var n'est pas dfinie et qu'elle n'a pas besoin de l'tre
               // il n'y a pas d'erreur
               if(((!isset($var))||($var == ""))&&($min == 0)){
                   return;
               }

               // Vrification min-max
               if(!$this->check_min_max($var, $min, $max)){
                   $this->set_error($error_msg);
                   return;
               }

               // vrification du type :
               // choix de la fonction correspondente
               $type_function = "check_type_".$type;
               // si la variable est un champs on boucle pour vrifier chaque element
               if(is_array($var)){

                  $i = 0;
                  while($var[$i]){

                      if(!$this->$type_function($var[$i])){
                           $this->set_error($error_msg);
                           return;
                      }
                      $i++;
                  }
               // sinon nous vrifions $var une fois
               }else{

                  if(!$this->$type_function($var)){
                      $this->set_error($error_msg);
                      return;
                  }

               }

               //  dfaut d'erreur, on retourne
               return;
      }

      function set_error($error_msg){
               $this->ok = FALSE;
               if((!in_array($error_msg,$this->error_msg))){ // pour ne pas rpter un mme message d'erreur.
                 $this->error_msg[] = $error_msg;
               }
      }

      // Cette fonction vrifie si la rponse $var rpond aux exigeances en terme de
      // nombre minimal et maximal de rponses.
      function check_min_max($var, $min, $max){

               if($min > $max){ //  moins que l'on dcide que $max  0 -> infinie?
                   echo "Erreur fatale de config dans min max pour";
                   var_dump($var);
                   exit;
               }

               if((!isset($var))||($var == "")){
                    $field = 0;
               }elseif(!is_array($var)){
                   $field = 1;
               }else{
                   $field = count($var);
               }

               if(($min <= $field)&&($field <= $max)){
                   return TRUE;
               }else{
                   return FALSE;
               }

               return FALSE; // En absence de rponse on choisi l'erreur
      }

      /**
      * @return void
      * @param $separator string separator
      * @desc Echoes error messages separated by $separator       
 	  */
      function echo_error_msg($separator){
               $i = 0;
               while($this->error_msg[$i]){
                      echo $this->error_msg[$i];
                      echo $separator;
                      $i++;
               }
      }
      
      /**
      * @return void
      * @param $separator string separator
      * @desc returns array of error messages
 	  */
      function get_error_msg(){
               if(empty($this->error_msg)) return array();
               return $this->error_msg;
      }

      function set_default($min, $max, $type, $error_msg){
                     $this->default_min = $min;
                     $this->default_max = $max;
                     $this->default_type = $type;
                     $this->default_error_msg = $error_msg;
      }

      function validate_default($variable_argument_number){
               $num_args = func_num_args();

               for ($index = 0; $index < $num_args; ++$index){
                     $var = func_get_arg($index);
                     $this->validate($var, $this->default_min, $this->default_max, $this->default_type, $this->default_error_msg);
               }
      }

      function check_type_int($var){ // this may not work because all the GET or POST values are strings.
               (is_int($var)) ? ($return = TRUE) : ($return = FALSE);
               return $return;
      }

      function check_type_string($var){
               (is_string($var)) ? ($return = TRUE) : ($return = FALSE);
               return $return;
      }

      function check_type_mail($var){
               $email_regexp = "^([-!#\$%&'*+./0-9=?A-Z^_`a-z{|}~ ])+@([-!#\$%&'*+/0-9=?A-Z^_`a-z{|}~ ]+\\.)+[a-zA-Z]{2,4}\$";
               return(eregi($email_regexp,$var)!=0);
      }

      function check_type_digit($var){
               return(eregi("^[[:digit:]]+$",$var)!=0);
      }

      function check_type_alpha($var){
               return(eregi("^[[:alpha:]]+$",$var)!=0);
      }

}



// Il est possible de crer ses propres types en ajoutant des classes enfants.
// Il faut nanmoins veiller  appeler le constructeur du parent.
// Si ce dernier n'est pas appel $this->ok sera NULL et non TRUE par dfaut.

/*
class my_validation extends VariableValidator {

      function my_validation(){
            parent::var_validator();
      }

      function check_type_blob($var){
               ($var == "blob") ? ($return = TRUE) : ($return = FALSE);
               return $return;
      }
}
*/
/*
En plus on pourrait tout vrifier qui vient par GET ou POST:
(mais est-ce bien utile)?

$val->validate_all("get", 1, 1, "string", "Vrifier vos entres"); // En paramtre est envoy la mthode
*/

?>
