<?php
/**
 * vim: set tabstop=4 :
 * vim: set number :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('plugins/bookmarks/util/BookmarkUtils.php');
require_once ('plugins/bookmarks/model/BookmarkServices.php');
require_once ('plugins/bookmarks/model/BookmarkFactory.php');

require_class ('RightsManagerImpl', 
	'plugins/bookmarks/RightsManagerImpl.php'); // added by Michael
require_class ('RequestCast', 
	'base/util/request/RequestCast.class.php'); // added by Michael
/**
 * The BookmarkSideBar Controller
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.bookmarks
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class BookmarkSidebarController extends ItemController
{
	/**
	 * Constructor. Makes sure that the appropriate operations are 
	 * instantiated.
	 */
	function BookmarkSidebarController ()
	{
		parent::ItemController ();
		$this->operations = new BookmarkServices ();
		$this->itemFactory = new BookmarkFactory ();

		$this->rightsManager = new RightsManagerImpl(); 

		$this->pluginName = 'bookmarks';
		$this->title = 'Booby - Bookmarks';
		$this->itemName = 'Bookmark';

		$this->expandName = 'bookmarkExpand';
	}

	/**
	 * Returns the title of this Controller
	 *
	 * @return string the title of this controller
	 */
	function getTitle ()
	{
		return "Booby - Bookmarks";
	}

	/**
	 * Returns the name of the item that is controller by this 
	 * controller
	 *
	 * @return string the name of the item that is controlled by this 
	 * controller
	 */
	function getItemName ()
	{
		return "Bookmark";
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions (like search, 
	 * import etc.)
 	 */
	function getActions ()
	{
		$dictionary = $this->getDictionary ();
		$actions=array(
			array (
				'name'=> $dictionary['actions'],
				'contents'=>
				array (
					array('href' =>
						'BookmarkController.php',
						'img' =>
						'<img 
						src="templates/sidebar/pics/home.gif"
						border="0">',
						'name' =>
						$dictionary['home']),
					array('href' => 'BookmarkSidebarController.php?action=add&parentId='.$this->getParentId (),
						'img' =>
						'<img 
						src="templates/sidebar/pics/add.gif"
						border="0">',
						'name' =>
						$dictionary['add']),
					array('href' =>
					'BookmarkSidebarController.php',
						'img' =>
						'<img
						src="templates/sidebar/pics/refresh.gif"
						border="0">',
						'name' =>
						$dictionary['refresh'])
					)
				),
			array (
				'name'=> $dictionary['view'],
				'contents' =>
				array (
					array('href' => 'BookmarkSidebarController.php?expand=*',
						'img' =>
						'<img
						src="templates/sidebar/pics/expand.gif"
						border="0">',
						'name' => $dictionary['expand']),
					array('href' => 'BookmarkSidebarController.php?expand=0',
						'img' =>
						'<img
						src="templates/sidebar/pics/collapse.gif"
						border="0">',
						'name' => $dictionary['collapse'])
				)
			)
		);
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "add":
				$this->addAction ();
				break;
			case "addBookmark":
				$this->addItemAction ();
				break;
			case "modify":
				$this->modifyAction ();
				break;
			case "modifyBookmark":
				$this->modifyItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode. If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "searchBookmarks":
				$this->searchItemAction ();
				break;
			case "deleteBookmark":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "showBookmark":
				$this->operations->updateVisiteCount ($this->getUserName (), $this->itemId);
				$bookmark = $this->operations->getItem
					($this->getUserName (), $this->itemId);
				header ("Location: " . $bookmark->locator);
   				exit;
				break;
			case "sort":
				$field = $_GET['field'];
				$this->sortAction ($field);
				$this->getShowItemsParameters ();
				break;
			default:
				$this->getShowItemsParameters ();
				break;
		}
	}

	function getTemplate ()
	{
			return "sidebar";
	}
}
//$controller = new BookmarkSidebarController ();
//$controller -> activate ();
//$controller -> display ();
?>
