<?php
/**
 * vim: set number : 
 * vim: set tabstop=4 :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Boby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('plugins/calendar/model/CalendarServices.php');
require_once ('plugins/calendar/model/CalendarPreferences.php');
require_once ('plugins/calendar/model/CalendarFactory.php');
require_once ('plugins/calendar/util/CalendarUtils.php');

require_class ('RightsManagerImpl', 'plugins/calendar/RightsManagerImpl.php');
require_class ('RequestCast', 'base/util/request/RequestCast.class.php');
/**
 * The Calendar Controller
 *
 * @author Barry Nauta April 2004
 * @package be.nauta.booby.plugins.calendar
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class CalendarController extends ItemController
{
	/**
	 * Calendar utilities
	 */
	var $calendarUtils;

	var $today;

	var $requestedDate;
	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function CalendarController ()
	{
		parent::ItemController ();
		$this->operations = new CalendarServices ();
		$this->preferences = new CalendarPreferences ();

		$this->rightsManager = new RightsManagerImpl();

		$this->pluginName = 'calendar';
		$this->title = 'Booby - Calendar';
		$this->itemName = 'Event';

		$this->calendarUtils = new CalendarUtils ();
		$this->itemFactory = new CalendarFactory ();

		$this->today = mktime (0,0,0, date('m'), date ('d'), date('y'));

		if (isset ($_GET['day']) && isset ($_GET['month']) 
			&& isset ($_GET['year']))
		{
			$this->requestedDate= mktime (0, 0, 0, 
					$_GET['month'], $_GET['day'], $_GET['year']); 
		}
		else if (isset ($_GET['month']) && isset ($_GET['year']))
		{
			$this->requestedDate= mktime (0, 0, 0, 
					$_GET['month'], 1, $_GET['year']); 
		}
		else if (isset ($_GET['year']))
		{
			$this->requestedDate= mktime (0, 0, 0, 
					1, 1, $_GET['year']); 
		}
		else if (isset ($_GET['date']))
		{
			$this->requestedDate= $_GET['date'];
		}
		else
		{
			$this->requestedDate= $this->today;
		}
	}

	/**
 	 * Returns the actions defined for this item only
 	 * Modified by Michael : added navigationMode and rightsmanagement
 	 *
 	 * @return array an array of item specific actions (like search, import etc.)
 	 */
	function getActions ()
	{
		$dictionary = $this->getDictionary ();

		/*
	 	 * Actions
		 */
		$actions[0]['name'] = $dictionary['actions'];

		if($this->rightsManager->isGranted($this->getParentId (), "add"))
			$actions[0]['contents'][] = array(
				'href' => 'CalendarController.php?action=add&parentId='.$this->getParentId (),
				'name' => $dictionary['add']
				);
		if($this->rightsManager->isGranted($this->getParentId (), "selectToday"))
			$actions[0]['contents'][] = array(
				'href' => 'CalendarController.php?action=selectToday',
				'name' => $dictionary['today']
				);
		/*
		 * Views
		 */
		$actions[1]['name'] = $dictionary['view'];
		if($this->rightsManager->isGranted($this->getParentId (), "view"))
		{
			$actions[1]['contents'][] = array('href' =>
				'CalendarController.php?action=showDay&date='.$this->requestedDate,
				'name' => $dictionary['dayView']);
			$actions[1]['contents'][] = array('href' =>
				'CalendarController.php?action=showWeek&date='.$this->requestedDate,
				'name' => $dictionary['weekView']);
			$actions[1]['contents'][] = array('href' =>
				'CalendarController.php?action=showMonth&date='.$this->requestedDate,
				'name' => $dictionary['monthView']);
			$actions[1]['contents'][] = array('href' =>
				'CalendarController.php?action=showYear&date='.$this->requestedDate,
				'name' => $dictionary['yearView']);
			$actions[1]['contents'][] = array('href' =>
				 'CalendarController.php?action=setModePublic&parentId='.
				 	$this->getParentId (),
			'name' => $dictionary['setModePublic']);
			$actions[1]['contents'][] = array('href' =>
				 'CalendarController.php?action=setModePrivate&parentId='.
				 	$this->getParentId (),
			'name' => $dictionary['setModePrivate']);
		}
		/*
		 * Sort
		 */
		//$actions[2]['name'] = $dictionary['sort'];
		/*
		if($this->rightsManager->isGranted($this->getParentId (), "sort"))
		{
			$actions[2]['contents'][] = array('href'=> 'CalendarController.php?action=sort&order=DESC&field=when_visited',
			'name' => $dictionary['last_visited']);
			$actions[2]['contents'][] = array('href'=> 'CalendarController.php?action=sort&order=DESC&field=visitCount',
			'name' => $dictionary['most_visited']);
			$actions[2]['contents'][] = array('href'=> 'CalendarController.php?action=sort&order=DESC&field=when_created',
			'name' => $dictionary['last_created']);
			$actions[2]['contents'][] = array('href'=> 'CalendarController.php?action=sort&order=DESC&field=when_modified',
			'name' => $dictionary['last_modified']);
			
		}
		*/	
		/*
		 * Preferences
		 */		
		if($this->rightsManager->isGranted($this->getParentId (), "preferences"))
		{
			$actions[3]['name'] = $dictionary['preferences'];
			$actions[3]['contents'][] = array('href'=> 'CalendarController.php?action=modifyPreferencesPre',
			'name' => $dictionary['modify']);
		}
		
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		// Asign 'today' and the 'requested date' (defaults to today)
		$this->renderEngine->assign ('today', $this->today);

		//die (print_r ($_GET));
		$this->renderEngine->assign ('requestedDate',$this->requestedDate);
		$this->renderEngine->assign ('dictionary',
			$this->getDictionary());
			
		// Now take a look at the action
		switch ($this->getAction ())
		{
			case "add":
				$this->directAction ($this->getAction ());
				$this->renderer = 'addEvent';
				break;
			// this is to show an Item in a special showItem Page
			case "showItem":
				$this->directAction ($this->getAction (), true);
				break;
			case "addItem":
				$this->addItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "modify":
				$this->modifyAction ();
				break;
			case "modifyItem":
				$this->modifyItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode. If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "searchItems":
				$this->searchItemAction ();
				break;
			case "deleteItem":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference
					($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['calendarStartOfWeek']=
						$this->preferences->getPreferenceValue
							($this->getUserName (), 'calendarStartOfWeek');
				$_SESSION['calendarOverlib']=
						$this->preferences->getPreferenceValue
							($this->getUserName (), 'calendarOverlib');

				$_SESSION['calendarDefaultView']=
						$this->preferences->getPreferenceValue 
							($this->getUserName(), 'calendarDefaultView');
				$this->renderer = 'modifyPreferences';
				$this->renderObjects=$_SESSION;
				break;
			case "selectToday":
				$this->getShowItemsParameters();
				break;
			case "showYear":
				$this->renderObjects =
					$this->operations->getMonthsAsArray	($this->requestedDate);
				$this->renderer = 'showYear';
				break;
			case "showDay":
				$this->renderer = 'showDay';
				$this->renderEngine->assign ('currentMonthValues',
					$this->operations->getDaysInMonthAsArrayPerWeek
						($this->requestedDate));
				//$this->renderEngine->assign ('renderObjects', 
				$this->renderObjects = 
					$this->operations->getEvents ($this->requestedDate);
				break;
			case "showWeek":
				$this->renderer = 'showWeek';
				//$this->renderEngine->assign ('renderObjects', 
				$this->renderObjects = 
					$this->operations->getWeekForDay ($this->requestedDate);
				break;
			case "showMonth":
				$this->renderObjects =
					$this->operations->getDaysInMonthAsArrayPerWeek
						($this->requestedDate);
				$this->renderer = 'showMonth';
				$m = date('m', $this->requestedDate);
				$d = date('d', $this->requestedDate);
				$y = date('y', $this->requestedDate);
				$previousMonth = mktime (0, 0, 0, $m-1, $d, $y);
				$nextMonth = mktime (0, 0, 0, $m+1, $d, $y);
				$this->renderEngine->assign('previousMonthValues',
					$this->operations->getDaysInMonthAsArrayPerWeek
						($previousMonth));
				$this->renderEngine->assign('nextMonthValues',
					$this->operations->getDaysInMonthAsArrayPerWeek
						($nextMonth));
				break;
			default:
				$this->getShowItemsParameters ();
				break;
		}
	}

	function getShowItemsParameters ()
	{
		switch ($_SESSION['calendarDefaultView'])
		{
			case "year": 
				$this->setAction ('showYear');
				break;
			case "month": 
				$this->setAction ('showMonth');
				break;
			case "week": 
				$this->setAction ('showWeek');
				break;
			default:
				$this->setAction ('showDay');
				break;
		}
		$this->activate ();
	}

	function getCalendarCurrentMonth ()
	{
	}

}
//$controller = new CalendarController ();
//$controller -> activate ();
//$controller -> display ();
?>
