<?php
/*
 * vim: set tabstop=4 :
 * vim: set number :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003  - 2004 Barry Nauta
 *
 * The Booby project is release under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/model/Services.php');
require_once ('plugins/calendar/model/CalendarFactory.php');
/**
 * Calendar class
 *
 * @author Barry Nauta
 * @date November 2003
 * @package be.nauta.booby.plugins.calendar.model
 * @copyright
 *
 * Copyright (c) 2003 Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <a href="http://www.gnu.org">www.gnu.org</a>
 * and look for licenses
 */
class CalendarServices extends Services
{

    function CalendarServices()
    {
	    parent::Services();
		$this->itemFactory = new CalendarFactory ();

		include ('plugins/calendar/sql/calendarQueries.php');
		$this->queries = $queries;
    }


	/**
	 * Get the days for the requested month in an array
	 * @param integer month the requested month, 1 for Jan.
	 * @param integer year the requested year
	 * @return integer 0 (for Sunday) through 6 (for Saturday)
	 */
	function getFirstDayInMonth ($date)
	{
    	$date = getdate(mktime(12, 0, 0, date ('m', $date), 1, date ('y', $date)));
    	$first = $date["wday"];
    	return $first;
	}

	/**
	 * Returns the number of days in the specified month/year
	 * combination. The year parameter is used for leap-year
	 * calculation
	 *
	 * @param integer month the requested month, 1 for Jan.
	 * @param integer year the requested year
	 * @return integer the number of days in the requested month
	 */
	function getNumberOfDaysInMonthOld ($month, $year)
	{
		if ($this->isLeapYear ($year))
		{
			$numberOfDaysPerMonth =
				array(31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
		}
		else
		{
			$numberOfDaysPerMonth =
				array(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
		}
		return $numberOfDaysPerMonth [$month-1];
	}

	function getNumberOfDaysInMonth ($date)
	{
		return date ('t', $date);
	}
	/**
	 * Is the specified year a leap year?
	 * @param integer the year for which we would like to know whether
	 * it is a leap-year
	 * @return boolean <code>true</code> if the year is a leap-year,
	 * <code>false</code> otherwise.
	 * @todo replace by date input and format 'L'
	 */
	function isLeapYearOld ($year)
	{
		$result = false;
		if ($year %4 == 0)
		{
			if ($year %100 == 0)
			{
				if ($year %400 == 0)
				{
					$result = true;
				}
			}
			else
			{
				$result = true;
			}
		}
		return $result;
	}


	function getMonthsAsArray ($date)
	{
		$year = date ('Y', $date);
		$result = array ();
		for ($i=1; $i<=12; $i++)
		{
			$date= mktime (0, 0, 0, $i, 1, $year); 

			$result [] = $this->getDaysInMonthAsArrayPerWeek ($date);
		}
		//die (print_r ($result));
		return $result;
	}

	function getDaysInMonthAsArrayPerWeek ($date)
	{
		$firstDay = $this->getFirstDayInMonth ($date);
		$numberOfDaysInMonth = $this->getNumberOfDaysInMonth ($date);

		$m = date ('m', $date);
		$y = date ('y', $date);	
		// max. 6 weeks in one month
		$weeks = array ();
		for ($currentWeekDay=$firstDay, $dayCount=1, $weekCount=0;
			$dayCount<=$numberOfDaysInMonth;
			$currentWeekDay++, $dayCount++)
		{
			$weekCount2 = date ('W', mktime (0, 0, 0, $m, $dayCount, $y));
			if ($currentWeekDay > 0 && $currentWeekDay < 7)
			{
				$weeks[$weekCount2][] = $dayCount;
			}
			else
			{
				$weeks[$weekCount2][] = $dayCount;
				$weekCount++;
				$currentWeekDay = 0;
			}
		}
		//die (print_r ($weeks));
    	return $weeks;
	}

	/**
	 * NOT USED
	 */
	function addItem ($userId, $item)
	{
			global $db;
			//die (print_r ($item));
			$now = date  ("Y-m-d H:i:s");
			$query = sprintf ($this->queries['addItem'],
				$userId,
				addslashes ($item->parentId),
				addslashes ($item->isParent),
				addslashes ($item->name),
				addslashes ($item->description),
				addslashes ($item->visibility),
				addslashes ($item->category),
				addslashes ($now),
				addslashes ($item->location),
				date ("Y-m-d H:i", $item->eventStartDate),
				date ("Y-m-d H:i", $item->eventEndDate));
			//die ('CalendarServices::addItem '.$query);
			$db -> Execute ($query) or die ($db->ErrorMsg ());
	}

	function getEvents ($date)
	{
			global $db;
			$now = date  ("Y-m-d H:i:s");
			$startDate = date ("Y-m-d H:i:s", $date);
			//die (date ('m',$date));
			$datePlusOne = date ("U", $date) + (60*60*24);
			$theDatePlusOne =  date ("Y-m-d H:i:s", $datePlusOne);
			$query = sprintf ($this->queries['getEvents'],
				$startDate,$theDatePlusOne);
				//die ($query);
			$rs = $db->Execute ($query) or die ($db->ErrorMsg().' '.$query);
			//die (print_r ($rs));
			return $this->itemFactory->resultSetToItems($rs);
	}


	function getWeekForDay ($date)
	{
			$result = array ();

			//$currentDayInWeek = date ('w', $date);
			$weekday =  (date('w', $date) + 6) % 7;
			//die (date ('D M j Y', $date));
			//$weekday = date ('w' , $date);
			$before = $weekday;
			$after = 6-$weekday;

			//die (date('D M j Y w', $date). '-'.$weekday.'-'.$before . '-'. $after);
			for ($i=$before; $i>0; $i--)
			{
					//$result [] = date ("Y-m-d", mktime(0,0,0, date('m', $date),(date('d', $date)-$i),date('Y', $date)));
					$result [] = mktime(0,0,0, date('m', $date),(date('d', $date)-$i),date('Y', $date));
			}
			//$result [] = date ("Y-m-d", $date);
			$result [] = $date;
			for ($j=1; $j<=$after; $j++)
			{
					//$result [] = date ("Y-m-d", mktime(0,0,0, date('m', $date),(date('d', $date)+$j),date('Y', $date)));
					$result [] = mktime(0,0,0, date('m', $date),(date('d', $date)+$j),date('Y', $date));
			}
			//die (print_r ($result));
			return $result;
	}
	/*
	function getPreviousMonth ($month, $year)
	{
			$result = array ();
			if ($month > 1)
			{
					$month--;
			}
			else
			{
					$month=12;
					$year--;
			}
			$result['month']=$month;
			$result['year']=$year;
			return $result;
	}

	function getNextMonth ($month, $year)
	{
			$result = array ();
			if ($month < 12)
			{
					$month++;
			}
			else
			{
					$month=1;
					$year++;
			}
			$result['month']=$month;
			$result['year']=$year;
			return $result;
	}
	*/
}
?>
