<?php
/**
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('plugins/contacts/util/Contact_Vcard_Parse.php');
require_once ('plugins/contacts/util/ContactUtils.php');
require_once ('plugins/contacts/model/ContactServices.php');
require_once ('plugins/contacts/model/ContactPreferences.php');

require_class ('RightsManagerImpl', 'plugins/contacts/RightsManagerImpl.php'); // added by Michael
require_class ('RequestCast', 'base/util/request/RequestCast.class.php'); // added by Michael
/**
 * The Contact Controller
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.contacts
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class ContactController extends ItemController
{
	/**
	 * Constructor. 
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function ContactController ()
	{
		parent::ItemController ();
		$this->operations = new ContactServices ();
		$this->preferences = new ContactPreferences ();
		$this->itemFactory = new ContactFactory ();

		$this->rightsManager = new RightsManagerImpl(); // added by Michael

		$this->pluginName = 'contacts';
		$this->title = 'Booby - Contacts';
		$this->itemName = 'Contact';
		$this->expandName = 'contactExpand';
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions 
	 * (like search, import etc.)
 	 */
	function getActions ()
	{
		$dictionary = $this->getDictionary ();
		
		// Actions
		$actions[0]['name']=$dictionary['actions'];
		$actions[0]['contents'][]=
					array('href' => 'ContactController.php?action=add&parentId='.$this->getParentId (),
						'name' => $dictionary['add']);
		$actions[0]['contents'][]=
					array('href' => 'ContactController.php?action=multipleSelectPre',
						'name' => 'Multiple Select');
		$actions[0]['contents'][]=
					array('href' => 'ContactController.php?action=import&parentId='.$this->getParentId (),
						'name' => $dictionary['import']);
		$actions[0]['contents'][]=
					array('href' => 'ContactController.php?action=export&parentId='.$this->getParentId (),
						'name' => $dictionary['export']);
		$actions[0]['contents'][]=
	    			array('href' => 'ContactController.php?action=search',
	        			'name' => $dictionary['search']);
						
		// View
		$actions[1]['name']=$dictionary['view'];
		$actions[1]['contents'][]=
					array('href' => 'ContactController.php?expand=*',
						'name' => $dictionary['expand']);
		$actions[1]['contents'][]=
						array('href' => 'ContactController.php?expand=0',
						'name' => $dictionary['collapse']);
		$actions[1]['contents'][]=
					array('href' => 'ContactController.php?action=setYahooTree&parentId='.$this->getParentId (),
						'name' => $dictionary['yahooTree']);
		$actions[1]['contents'][]=
					array('href' => 'ContactController.php?action=setExplorerTree&parentId='.$this->getParentId (),
						'name' => $dictionary['explorerTree']);
		$actions[1]['contents'][]=
					array('href' => 'ContactController.php?action=setLineBasedTree&parentId='.$this->getParentId (),
						'name' => $dictionary['lineBasedTree']);
		$actions[1]['contents'][] = 
					array('href' => 'ContactController.php?action=setModePublic&parentId='.$this->getParentId (),
						'name' => $dictionary['setModePublic']);
		$actions[1]['contents'][] = 
					array('href' => 'ContactController.php?action=setModePrivate&parentId='.$this->getParentId (),
					'name' => $dictionary['setModePrivate']);
						
		// Sort
		$actions[2]['name']=$dictionary['sort'];
		$actions[2]['contents'][]=
					array('href'=>'ContactController.php?action=sort&order=ASC&field=alias',
						'name'=> $dictionary['alias']);
		$actions[2]['contents'][]=
					array('href'=>'ContactController.php?action=sort&order=ASC&field=email1',
						'name'=> $dictionary['email'].' 1');
		$actions[2]['contents'][]=
					array('href'=>'ContactController.php?action=sort&order=ASC&field=organization',
						'name'=> $dictionary['organization']);

		// Preferences
		$actions[3]['name']=$dictionary['preferences'];
		$actions[3]['contents'][]=
					array ('href'=>'ContactController.php?action=modifyPreferencesPre',
						'name'=>$dictionary['modify']);
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "add":
				$this->addAction ();
				break;
			case "showItem":
			case "modify":
				$this->modifyAction ();
				break;
			case "deleteContact":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "searchContacts":
				$this->searchItemAction ();
				break;
			// Added by Michael. Default navigation mode. If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "search":
			case "export":
			case "import":
				$this->renderer = $this->getAction().'Contacts';
				break;
			case "addContact":
				$this->addItemAction ();
				break;
			case "modifyContact":
				$this->modifyItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "importContacts":
				$importType = $_POST['importType'];
				$importFile = $_FILES['importFile'];
				$visibility = $_POST['visibility'];
				$parentId = $_POST['parentId'];
				error_reporting (0);
				if ($importType == 'VCard')
				{
					$parser = new Contact_Vcard_Parse ();
					$result = $parser->fromFile ($importFile['tmp_name']);
					$contacts = $this->itemFactory->vcardsToContacts ($result);
					for ($i=0; $i<count($contacts); $i++)
					{
						$contacts[$i]->parentId = $parentId;
						$contacts[$i]->visibility=$visibility;
						$this->operations->addItem
							($this->getUserName(), $contacts[$i]);
					}
				}
				else if ($importType == 'Opera')
				{
					$contactUtils = new ContactUtils ();
					$contactUtils->importOperaContacts ($this->getUserName(), $importFile ['tmp_name'], $this, $parentId, $visibility);
				}
				else
				{
					die ('Unsupported contact import type:-'.$importType.'-');
				}
		        $this->getShowItemsParameters ();
				break;
			case "exportContacts":
					$contactUtils = new ContactUtils ();
					$exportType = $_POST['exportType'];
					$parentId = $_POST['parentId'];
					if ($exportType == 'Opera')
					{
						Header ("Content-type: text/plain");
						echo ("Opera Hotlist version 2.0\n\n");

						$contactUtils ->exportOperaContacts
								($this->getUserName(), $parentId, $this);
					}
					else if ($exportType == 'VCard')
					{
						Header ("Content-type: text/plain");
						$contactUtils -> exportVCards 
								($this->getUserName(), $parentId, $this);
					}
					else 
					{
							die ('Unsupported type: '.$exportType);
					}
					exit ();
			case "setYahooTree":
				$_SESSION['contactTree']='Yahoo';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['contactTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
			case "setLineBasedTree":
				$_SESSION['contactTree']='LineBased';
				$this->getShowItemsParameters ();
				break;
			case "sort":
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->sortAllAction ($field, $order);
				break;
			case "modifyPreferencesPre":
				$this->renderObjects = 
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->renderer = 'showContacts';
				
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['contactTree']=
					$this->preferences->getPreferenceValue ($this->getUserName (), 'contactTree');
				$_SESSION['contactOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'contactOverlib');
				$_SESSION['contactYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'contactYahooTreeColumnCount');
				$this->getShowItemsParameters ();
				break;
			case "multipleSelectPre":
				$this->multipleSelectAction ();
				break;
			case "multipleSelectPost":
				$itemIds = array_keys ($_POST, "itemId");
				if (isset ($_POST['move']))
				{
					$this->moveMultipleAction ($itemIds);
				}
				else if (isset ($_POST['delete']))
				{
					foreach ($itemIds as $itemId)
					{
						$this->operations->deleteItem ($this->getUserName(), $itemId);
					}
					$this->getShowItemsParameters ();
				}
				break;
			case "moveMultipleItemsPost":
				$itemIds = explode (",", $_GET['itemIds']);
				$parentId = $_GET['parentId'];
				foreach ($itemIds as $itemId)
				{
					$this->operations->moveItem ($this->getUserName(), $itemId, $parentId);
				}
				$this->getShowItemsParameters ();
				break;
			default:
				if (!isset ($_SESSION['contactTree']))
				{
					$_SESSION['contactTree']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'contactTree');
				}
				if (!isset ($_SESSION['contactOverlib']))
				{
					$_SESSION['contactOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'contactOverlib');
				}
				if (!isset ($_SESSION['contactYahooTreeColumnCount']))
				{
					$_SESSION['contactYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'contactYahooTreeColumnCount');
				}
				$this->getShowItemsParameters ();
				break;
			}
	}


}
//$controller = new ContactController ();
//$controller -> activate ();
//$controller -> display ();
?>
