<?php
/*
 * vim: set number :
 * vim: set tabstop=4 : 
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/model/ItemFactory.php');
require_once ('plugins/contacts/model/Contact.php');

require_class('RequestCast', 'base/util/request/RequestCast.class.php');
require_class('ClassHelper', 'base/util/ClassHelper.class.php'); 
/**
 * ContactFactory
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.contacts.model
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta 
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class ContactFactory extends ItemFactory
{
		/**
		 * Default constructor
		 */
		function ContactFactory ()
		{
			parent::ItemFactory ();
			$this->requestCast = new RequestCast("Contact"); 
		}
			
				
		/**
		 * Returns the type of this specific item
		 * @return string the type of this specific item: 
		 * <code>Contact</code>
		 */
		function getType ()
		{
			return "Contact";
		}
		
		/**
		 * Removes some characters from the input string
		 * These characters are: ';' and ','
		 * @private 
		 *
		 * @param string input the input string
		 * @return string the modified string
		 * @todo move this function to the StringUtils class?
		 */
		function removeSpecialChars ($input)
		{
			$result = str_replace(';', '', $input);
			$result = str_replace(',', '', $result);
			$result = str_replace("'", '', $result);
			$result = str_replace('"', '', $result);
			return $result;
		}
		
		/**
		 * Factory method. Takes the input received from the vCard 
		 * parsing class and returns an array of contacts
		 *
		 * @param object vcards an array containing vCard information 
		 * (more information: 
		 * <a href=http://ciaweb.net/free/contact_vcard_parse/"
		 * >ciaweb.net/free/contact_vcard_parse/</a> )
		 * @return array an array of contacts
		 */
		function vcardsToContacts ($vcards)
		{
			// the resulting contacts
			$result = array ();
			// seperator used in the address
			$sep = " ";
		
			// loop over the input array
			for ($i=0; $i<count($vcards); $i++)
			{
				$currentContact = new Contact (
					null, null, null, null,
					null, null, null, null,
					null, null, null, null,
					null, null, null, null,
					null, null, null, null,
					null, null, null, null,
					null, null);
		
				$currentArray = $vcards[$i];
				// TBD TODO FIXME BARRY, what to do with the names, 
				// we should perhaps
				// install some additional checks: if FN but !N etc
				$name = //$this->removeSpecialChars 
					($currentArray['FN'][0]['value'][0]);
				if ($name != null && trim($name) != "")
				{
					$currentContact->name =$name;
				}
				$name = // $this->removeSpecialChars 
					($currentArray['N'][0]['value'][0]);
				if ($name != null && trim($name) != "")
				{
					$currentContact->name =$name;
				}
					
				$currentContact->email1 = 
					$currentArray['EMAIL'][0]['value'][0];
				$currentContact->email2 = 
					$currentArray['EMAIL'][1]['value'][0];
				$currentContact->email3 = 
					$currentArray['EMAIL'][2]['value'][0];
				$addresses = $currentArray['ADR'];
				//die ($currentContact->toString());
				if ($addresses != null && count($addresses) > 0)
				{
					for ($j=0; $j<count($addresses); $j++)
					{
						$addr = $addresses[$j];
						$values = $addr['value'];
						if ($addr['params']['TYPE'][0] == 'WORK')
						{
							//die (print_r($values));
							$theAddress = $values['pob'][0] . $sep .
								$values['extended'][0] . $sep .
								$values['street'][0] . $sep .
								$values['locality'][0] . $sep .
								$values['region'][0] . $sep .
								$values['postcode'][0] . $sep .
								$values['country'][0] . $sep;
							//die ($theAddress);
							$currentContact->org_address=
								//$this->removeSpecialChars 
								($theAddress); 
								//$theAddress;
							//die ($currentContact->toString ());
						}
						else if ($addr['params']['TYPE'][0] == 'HOME')
						{
							//die (print_r($values));
							$homeAddress = 
							//$this->removeSpecialChars (
								$values['pob'][0] . $sep .
								$values['extended'][0] . $sep .
								$values['street'][0] . $sep .
								$values['locality'][0] . $sep .
								$values['region'][0] . $sep .
								$values['postcode'][0] . $sep .
								$values['country'][0] . $sep
							//)
							;
							$currentContact->address=
								$homeAddress;
						}
					}
				}
				$currentContact->organization =
					//$this->removeSpecialChars 
					($currentArray['ORG'][0]['value'][0]);
				$currentContact->jobTitle =
					//$this->removeSpecialChars 
						($currentArray['TITLE'][0]['value'][0]);
				$currentContact->alias =
					//$this->removeSpecialChars
						($currentArray['NICKNAME'][0]['value'][0]);
				$tel = $currentArray['TEL'];
				for ($k=0; $k<count($tel); $k++)
				{
					$currentTel = $tel[$k];
		
					if ($currentTel['params']['TYPE'][0] == 'WORK' )
					{
						if ($currentTel['params']['TYPE'][1]
							== 'VOICE')
						{
							$currentContact->tel_work 
								=$currentTel['value'][0];
						}
						else if ($currentTel['params']['TYPE'][1] == 'FAX')
						{
							$currentContact->faximile 
								=$currentTel['value'][0];
						}
					}
					else if ($currentTel['params']['TYPE'][0] ==
						'HOME')
					{
						$currentContact->tel_home 
							=$currentTel['value'][0];
					}
					else if ($currentTel['params']['TYPE'][0] ==
						'CELL')
					{
						$currentContact->mobile 
							=$currentTel['value'][0];
					}
				}
				$currentContact->webaddress1 = 
					$currentArray['URL'][0]['value'][0];
				$currentContact->webaddress2 = 
					$currentArray['URL'][1]['value'][0];
				$currentContact->webaddress3 = 
					$currentArray['URL'][2]['value'][0];
				
				$currentContact->description =
					$currentArray['NOTE'][0]['value'][0];
		
		
				//$currentContact->
				$result [] = $currentContact;
			}
			return $result;
		}
}
?>
