<?php
/*
 * vim: set number:
 * vim: set tabstop=4 :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('plugins/contacts/model/Contact.php');
require_once ('plugins/contacts/model/ContactFactory.php');
require_once ('base/model/Services.php');
/**
 * Services for contacts
 *
 * @author Barry Nauta March 2003
 * @package be.nauta.booby.plugins.contacts.model
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class ContactServices extends Services
{

	/**
	 * Default constructor
	 */
	function ContactServices ()
	{
		parent::Services();
		$this->itemFactory = new ContactFactory ();

		include ('plugins/contacts/sql/contactQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds a contact for a user
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the contact to be added
	 *
     	 * @return integer last know id. This is the id of the contact
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem ($userId, $item)
	{
		global $db;
		$now = date ("Y-m-d H:i:s");

		// execute the query
		$query = sprintf ($this->queries['addItem'],
			$userId,
			addslashes ($item->parentId),
			addslashes ($item->isParent),
			addslashes ($item->name),
			addslashes (trim ($item->description)),
			addslashes ($item->visibility),
			addslashes ($item->category),
			addslashes ($item->when_created),
			addslashes ($item->when_modified),
			addslashes ($item->alias),
			addslashes (trim ($item->address)),
			addslashes ($item->birthday),
			addslashes ($item->mobile),
			addslashes ($item->faximile),
			addslashes ($item->tel_home),
			addslashes ($item->tel_work),
			addslashes ($item->organization),
			addslashes (trim ($item->org_address)),
			addslashes ($item->job),
			addslashes ($item->email1),
			addslashes ($item->email2),
			addslashes ($item->email3),
			addslashes ($item->webaddress1),
			addslashes ($item->webaddress2),
			addslashes ($item->webaddress3));
//		die ($query);

		$db->Execute($query) or 
				die ("Could not add contact.".
				$db->ErrorMsg () . " " . $query);

		// fetch the last known id
		// todo this is generic code and is candidate to move to the base Services class
		$query = $this->queries['lastItemInsertId'];
		$result = $db->Execute ($query) or
			die ("Could not retrieve last insert id for contact. ".
			$db->ErrorMsg () . " " . $query);

        return $result->fields[0];
	}

	/**
	 * Modifies a contact.
	 *
 	 * @param integer userId the identifier for the user who modifies a contact
	 * @param object item the modified contact
	 */
	function modifyItem ($userId, $item)
	{
		//die ("ContactService:: modifyItem ".print_r ($item));
		global $db;
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['modifyItem'],
			$now, 
			addslashes ($item->name), 
			addslashes ($item->parentId), 
			addslashes ($item->visibility),
			addslashes ($item->job), 
			addslashes ($item->alias), 
			addslashes ($item->organization),
			addslashes (trim ($item->org_address)), 
			addslashes ($item->tel_home), 
			addslashes ($item->tel_work), 
			addslashes ($item->faximile), 
			addslashes ($item->mobile), 
			addslashes (trim ($item->address)), 
			addslashes ($item->birthday),
			addslashes (trim ($item->description)), 
			addslashes ($item->email1), 
			addslashes ($item->email2), 
			addslashes ($item->email3),
			addslashes ($item->webaddress1), 
			addslashes ($item->webaddress2), 
			addslashes ($item->webaddress3),
			$item->itemId
		);
		$db->Execute($query)
			or die ("Error modifying item: " .
	 		$db->ErrorMsg() . " " . $query);
	}

}
?>
