<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ("base/view/TreeDelegate.php");
/**
 * Used in combination with the PHPItemTree class
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.contacts.view
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class ContactExplorerTreeDelegate extends TreeDelegate
{
	/**
	 * Default constructor
	 */
	function ContactExplorerTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div><script language="JavaScript" src="base/view/javascript/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>';

		if ($item->itemId == 0)
		{
			$resultString .= $this->configuration['icons']['root'];
		}
		else
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a>';
		}
		return $resultString;
	}
	
	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';
								
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}
	
		if ($isExpanded)
		{
			$res = $tree->createExpandedListWithout ($item->itemId);
			
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?expand=' . implode (',', $res);
			$resultString .= '&parentId='.$tree->root->itemId;
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['minus'];
			$resultString.= '</a>';
			
			$resultString.= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['folder_open'];
			$resultString .= '</a>';
		}
		else
		{
			// ???
			$linkExpand = "";
			// ???
			if (!$tree->isExpanded ($item->itemId) && $tree->expanded != null)
			{
				$linkExpand .= implode(",", $tree->expanded).",".$item->itemId;
			}
			else 
			{
				$linkExpand = $item->itemId;
			}
			if ($item->parentId != null)
			{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '?expand=' . $linkExpand;
				//$resultString .= '&parentId='.$item->parentId;
				$resultString .= '">';
			}
			else
			{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '?expand='.$linkExpand.'">';
			}
			$resultString .= $this->configuration['icons'] ['plus'];
			$resultString .= '</a>';
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons'] ['folder_closed'];
			$resultString .= '</a>';
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';
		
		$resultString .= '</td></tr>';
		return $resultString;
	}
	
	
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}
		if ($lastNode)
		{
			$resultString .= $this->configuration['icons']['corner'];
		}	
		else
		{
			$resultString .= $this->configuration['icons']['tee'];
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['node'];
		$resultString .= '</a>';


		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
			if ($item->alias != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['alias'].":</b></td>";
				$popUp .= "<td>".$item->alias."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->email1 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['email']."&nbsp;1:</b></td>";
				$popUp .= "<td>".$item->email1."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->email2 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['email']."&nbsp;2:</b></td>";
				$popUp .= "<td>".$item->email2."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->email3 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['email']."&nbsp;3:</b></td>";
				$popUp .= "<td>".$item->email3."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->webaddress1 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['webaddress']."&nbsp;1:</b></td>";
				$popUp .= "<td>".$item->webaddress1."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->webaddress2 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['webaddress']."&nbsp;2:</b></td>";
				$popUp .= "<td>".$item->webaddress2."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->webaddress3 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['webaddress']."&nbsp;3:</b></td>";
				$popUp .= "<td>".$item->webaddress3."</td>";
				$popUp .= "</tr>";
			} 
			if ($item->tel_home != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['tel_home'].":</b></td>";
				$popUp .= "<td>".$item->tel_home."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->tel_work != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['tel_work'].":</b></td>";
				$popUp .= "<td>".$item->tel_work."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->mobile != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>G.S.M.:</b></td>";
				$popUp .= "<td>".$item->mobile."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->faximile != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['faximile'].":</b></td>";
				$popUp .= "<td>".$item->faximile."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->description != null)
			{
				$popUp .= "<tr>";
				$popUp .= '<td colspan="2">'.$item->description."</td>";
				$popUp .= "</tr>"; 
			}
			$popUp .= "</table>";
		}
		
		$resultString .= "<a href='";
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . "' ";
		if ($this->configuration['overlib'])
		{
			$resultString .= $this->overLib ($item->name, $popUp);
		}
		$resultString .= 'alt="'. $this->stringUtils->urlEncode ($this->stringUtils->gpcAddSlashes ($item->name)) . '" target=_new>';
		$resultString .= $item->name;
		$resultString .= '</a>';
	
		$resultString .= '</td></tr>';
		return $resultString;
	}	
}
?>
