<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is releases under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ("base/view/TreeDelegate.php");
/**
 * Used in combination with the Tree class
 *
 * @author Barry Nauta January 2004
 * @package be.nauta.booby.plugins.contacts.view
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class ContactLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function ContactLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div><script language="JavaScript" src="base/view/javascript/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>';

		if ($item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		return $resultString;
	}
	
	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';
		
		$resultString .= '<br />';
		return $resultString;
	}
	
	function drawLinesHeader ($parentId)
	{
		$resultString = '<td colspan="8"></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['name'];
		$resultString .= $this->sortArrows ('name', $parentId);
		$resultString .= '</b></td>';
		
		$resultString .= '<td><b>'.$this->configuration['dictionary']['email'];
		$resultString .= $this->sortArrows ('email1', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['mobile'];
		$resultString .= $this->sortArrows ('mobile', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['tel_work'];
		$resultString .= $this->sortArrows ('tel_work', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['tel_home'];
		$resultString .= $this->sortArrows ('tel_home', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['webaddress'];
		$resultString .= $this->sortArrows ('webaddress1', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}
		// header with two icons and overlib popup
		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'].'?itemId=';
		$resultString .= $item->itemId.'&action=modify" ';
		$resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
		$resultString .= '</td>';
		
		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?itemId='.$item->itemId;
		$resultString .= '&parentId='.$item->parentId;
		$resultString .= '&action=deleteContact" ';
		// delete confirmation
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';
		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'].'?itemId='.$item->itemId.'&action=modify" ';
		if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib ($item->name, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->name, 30). '</b></a>';
		$resultString .= '</td>';
		
		$resultString .= '<td><a href="mailto:'.$item->email1.'">'.$item->email1.'</a></td>';
		$resultString .= '<td>';

		if ($item->mobile != null)
		{
			$resultString .= $item->mobile;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';
		$resultString .= '<td>';
		if ($item->tel_work != null)
		{
			$resultString .= $item->tel_work;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';
		$resultString .= '<td>'.$item->tel_home.'</td>';
		if ($item->webaddress1 != null)
		{
			$resultString .= '<td><a href="'.$item->webaddress1.'">'.$item->webaddress1.'</td>';
		}
		else
		{
			$resultString .= '<td>&nbsp;</td>';
		}
		return $resultString;
	}
	
	function overlibPopup ($item)
	{
		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
			if ($item->alias != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['alias'].":</b></td>";
				$popUp .= "<td>".$item->alias."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->email1 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['email']."&nbsp;1:</b></td>";
				$popUp .= "<td>".$item->email1."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->email2 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['email']."&nbsp;2:</b></td>";
				$popUp .= "<td>".$item->email2."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->email3 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['email']."&nbsp;3:</b></td>";
				$popUp .= "<td>".$item->email3."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->webaddress1 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['webaddress']."&nbsp;1:</b></td>";
				$popUp .= "<td>".$item->webaddress1."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->webaddress2 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['webaddress']."&nbsp;2:</b></td>";
				$popUp .= "<td>".$item->webaddress2."</td>";
				$popUp .= "</tr>"; 
			} 
			if ($item->webaddress3 != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['webaddress']."&nbsp;3:</b></td>";
				$popUp .= "<td>".$item->webaddress3."</td>";
				$popUp .= "</tr>";
			} 
			if ($item->tel_home != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['tel_home'].":</b></td>";
				$popUp .= "<td>".$item->tel_home."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->tel_work != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['tel_work'].":</b></td>";
				$popUp .= "<td>".$item->tel_work."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->mobile != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>G.S.M.:</b></td>";
				$popUp .= "<td>".$item->mobile."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->faximile != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['faximile'].":</b></td>";
				$popUp .= "<td>".$item->faximile."</td>";
				$popUp .= "</tr>"; 
			}
			if ($item->description != null)
			{
				$popUp .= "<tr>";
				$popUp .= '<td colspan="2">'.$item->description."</td>";
				$popUp .= "</tr>"; 
			}
			$popUp .= "</table>";
		}
		return $popUp;
	}
}
?>
