<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ("base/view/TreeDelegate.php");
/**
 * Used in combination with the Tree class
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.contacts.view
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class ContactYahooTreeDelegate extends TreeDelegate
{
	/**
	 * Default constructor
	 */
	function ContactYahooTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '';
		if ($item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		return $resultString;
	}
	
	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons'] ['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';
		
		$resultString .= '<br />';
		return $resultString;
	}
	
	
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString = '<table border="0" valign="top" width="220" bgcolor="#bbbbbb">';

		$resultString .= '<tr>';
		$resultString .= '<td class="menu" align="left" width="40">';
		$resultString .= '<a ';
		$resultString .= 'href="ContactController.php?itemId='.$item->itemId.'&action=modify"';
		$resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
		$resultString .= '<a ';
		$resultString .= 'href="ContactController.php';
		$resultString .= '?itemId='.$item->itemId;
		$resultString .= '&parentId='.$item->parentId;
		$resultString .= '&action=deleteContact"';
		// delete confirmation
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';

		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td>';
		$resultString .= '<td class="menu"><b>';
		$resultString .= $this->stringUtils->truncate($item->name, 20);
		$resultString .= '</b>';
		$resultString .= '</td>';
		$resultString .= '</tr>';
		
		if ($item->alias != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['alias'];
			$resultString .= ':</td>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->stringUtils->truncate ($item->alias, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->email1 != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['email'].'&nbsp;1:';
			$resultString .= '</td>';
			$resultString .= '<td class="contact">';
			$resultString .= '<a ';
			$resultString .= 'href="mailto:'.$item->email1.'">';
			$resultString .= $this->stringUtils->truncate ($item->email1, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->email2 != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['email'].'&nbsp;2:';
			$resultString .= '</td>';
			$resultString .= '<td class="contact">';
			$resultString .= '<a ';
			$resultString .= 'href="mailto:'.$item->email2.'">';
			$resultString .= $this->stringUtils->truncate ($item->email2, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->email3 != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['email'].'&nbsp;3:';
			$resultString .= '</td>';
			$resultString .= '<td class="contact">';
			$resultString .= '<a ';
			$resultString .= 'href="mailto:'.$item->email3.'">';
			$resultString .= $this->stringUtils->truncate ($item->email3, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->webaddress1 != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['webaddress'].'&nbsp;1:';
			$resultString .= '</td>';
			$resultString .= '<td class="contact">';
			$resultString .= '<a ';
			$resultString .= 'href="'.$item->webaddress1.'">';
			$resultString .= $this->stringUtils->truncate ($item->webaddress1, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->webaddress2 != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['webaddress'].'&nbsp;2:';
			$resultString .= '</td>';
			$resultString .= '<td class="contact">';
			$resultString .= '<a ';
			$resultString .= 'href="'.$item->webaddress2.'">';
			$resultString .= $this->stringUtils->truncate ($item->webaddress2, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->webaddress3 != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['webaddress'].'&nbsp;3:';
			$resultString .= '</td>';
			$resultString .= '<td class="contact">';
			$resultString .= '<a ';
			$resultString .= 'href="'.$item->webaddress3.'">';
			$resultString .= $this->stringUtils->truncate ($item->webaddress3, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->tel_work != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['tel_work'];
			$resultString .= ':</td>';
			$resultString .= '<td class="contact">';
			$resultString .= $item->tel_work;
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->tel_home != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['tel_home'];
			$resultString .= ':</td>';
			$resultString .= '<td class="contact">';
			$resultString .= $item->tel_home;
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->mobile != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['mobile'];
			$resultString .= ':</td>';
			$resultString .= '<td class="contact">';
			$resultString .= $item->mobile;
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->faximile != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->configuration['dictionary']['faximile'];
			$resultString .= ':</td>';
			$resultString .= '<td class="contact">';
			$resultString .= $item->faximile;
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->description != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td colspan="2" bgcolor="#ffffff">';
			$resultString .= $this->stringUtils->truncate ($item->description, 30);
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		$resultString .= "<tr><td></td><td></td></tr>";
		$resultString .= '</table>';

		return $resultString;
	}	
}
?>
