<?php
/**
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');

require_once ('base/model/InformationServices.php');
require_once ('base/model/InformationFactory.php');
require_once ('plugins/genealogy/model/PersonServices.php');
require_once ('plugins/genealogy/model/PersonFactory.php');
require_once ('plugins/genealogy/model/RelationShipServices.php');
require_once ('plugins/genealogy/model/RelationShipFactory.php');

require_class ('RightsManagerImpl', 'plugins/genealogy/RightsManagerImpl.php'); // added by Michael
require_class ('RequestCast', 'base/util/request/RequestCast.class.php'); // added by Michael
/**
 * The Genealogy Controller
 *
 * @author Barry Nauta January 2004
 * @package be.nauta.booby.plugins.genealogy
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta 
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class GenealogyController extends ItemController
{
	var $personServices;
	var $informationServices;
	var $relationShipServices;

	/**
	 * Constructor.
	 * 
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function GenealogyController ()
	{
		parent::ItemController ();
		$this->operations = new PersonServices ();
		$this->personMode ();

		$this->rightsManager = new RightsManagerImpl(); 

		$this->pluginName = 'genealogy';
		$this->title = 'Booby - Genealogy';
		$this->itemName = 'Person';

		$this->personServices = new PersonServices ();
		$this->informationServices = new InformationServices ();
		$this->relationShipServices = new RelationShipServices ();

		$this->expandName = 'genealogyExpand';
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions 
	 * (like search, import etc.)
 	 */
	function getActions ()
	{
		$dictionary = $this->getDictionary ();
		$actions=array(
			array (
				'name'=> $dictionary['actions'],
				'contents'=>
				array (
					array('href' => 'GenealogyController.php?action=add&parentId='.$this->getParentId (),
						'name' => $dictionary['add']),
//					array('href' => 'GenealogyController.php?action=import',
//						'name' => $dictionary['import']),
//					array('href' => 'GenealogyController.php?action=export',
//						'name' => $dictionary['export']),
					array('href' => 'GenealogyController.php?action=search',
						'name' => $dictionary['search'])
					)
				),
				/*
			array (
				'name'=> $dictionary['view'],
				'contents' =>
				array (
					array('href' => 'GenealogyController.php?expand=*',
						'name' => $dictionary['expand']),
					array('href' => 'GenealogyController.php?expand=0',
						'name' => $dictionary['collapse']),
					array('href' => 'GenealogyController.php?action=setPedigreeTree&parentId='.$this->getParentId (),
						'name' => $dictionary['pedigreeTree']),
					array('href' => 'GenealogyController.php?action=setYahooTree&parentId='.$this->getParentId (),
						'name' => $dictionary['yahooTree']),
					array('href' => 'GenealogyController.php?action=setExplorerTree&parentId='.$this->getParentId (),
						'name' => $dictionary['explorerTree'])
				)
			),
			*/
			array (
				'name'=>$dictionary['sort'],
				'contents'=>
				array (
					array('href'=> 'GenealogyController.php?action=sort&order=DESC&field=when_visited',
						'name' => $dictionary['last_visited']),
					array('href'=> 'GenealogyController.php?action=sort&order=DESC&field=visitCount',
						'name' => $dictionary['most_visited']),
					array('href'=> 'GenealogyController.php?action=sort&order=DESC&field=when_created',
						'name' => $dictionary['last_created']),
					array('href'=> 'GenealogyController.php?action=sort&order=DESC&field=when_modified',
						'name' => $dictionary['last_modified'])
				)
			)
			/*
			array (
				'name'=> 'Help',
				'contents' =>
				array (
					array('href' => '',
						'name' => $dictionary['bookmark_help'])
				)
			),
			*/
		);
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "add":
				$this->addAction ();
				break;
			case "addItem":
				$this->addItemAction ();
				break;
			case "modifyPersonPre":
				$this->renderObjects = $this->personServices->getItem($this->getUserName (), $_GET['itemId']);
				$this->renderer='modifyPerson';
				break;
			case "modifyItem":
				$this->modifyItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "addInformationPre":
				if (isset ($_GET['referingType']))
				{
					$this->renderEngine->assign ('referingType', $_GET['referingType']);
				}
				else
				{
					$this->renderEngine->assign ('referingType', $_POST['referingType']);
				}
				$this->informationMode ();
				$this->addAction ();
				break;
			case "showInformation":
				$this->renderObjects = $this->personServices->getItemWithRelationShipsAndInformation($this->getUserName (), $_GET['referingId']);
				$this->renderEngine->assign ('referingType', $_GET['referingType']);
				$this->renderEngine->assign ('referingId', $_GET['referingId']);
				$this->renderer='showInformation';
				break;
			case "modifyInformationPre":
				$this->renderObjects = $this->personServices->getItemWithRelationShipsAndInformation($this->getUserName (), $_GET['referingId']);
				$this->renderEngine->assign ('referingType', $_GET['referingType']);
				$this->renderEngine->assign ('referingId', $_GET['referingId']);
				$this->renderer='showInformation';
				break;
			case "addInformationPost":
				$this->informationMode ();
				$this->addItemAction ();
				$this->personMode ();

				$this->renderObjects = $this->personServices->getItemWithRelationShipsAndInformation($this->getUserName(), $_POST['referingId']);
				$this->renderEngine->assign ('referingType', $_POST['referingType']);
				$this->renderEngine->assign ('referingId', $_POST['referingId']);
				$this->renderer='showInformation';
				break;
			case "deleteInformation":
				$this->informationMode ();
				$this->deleteItemAction ();
				$this->itemId = $_POST['referingId'];
				if ($_POST['referingType']=='PERSON')
				{
				$this->renderObjects = $this->personServices->getItemWithRelationShipsAndInformation($this->getUserName (), $_POST['referingId']);
				$this->renderEngine->assign ('referingType', $_POST['referingType']);
				$this->renderEngine->assign ('referingId', $_POST['referingId']);
				$this->renderer='showInformation';
//					$this->personMode ();
//					$this->modifyAction ();
				}
				break;
			case "modifyInformationPre":
				$this->informationMode ();
				$this->modifyAction ();
				break;
			case "modifyInformationPost":
				$this->informationMode ();
				$this->modifyItemAction ();
				$this->personMode ();
				$this->itemId = $_POST['referingId'];
				$this->getShowItemsParameters ();
				$this->modifyAction ();
				break;
			case "showRelations":
				$this->renderObjects = $this->personServices->getItemWithRelationShipsAndInformation($this->getUserName (), $_GET['referingId']);
				$this->renderer='showRelationShips';
				break;
			case "modifyRelationsPre":
				$this->renderObjects = $this->personServices->getItemWithRelationShipsAndInformation($this->getUserName(), $_GET['referingId']);
				$this->renderer='modifyRelationShips';
				break;
				/*
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
				*/
			case "import":
			case "export":
			case "search":
				$this->renderer = $this->getAction ().'Item';
				break;
			case "searchItems":
				$this->searchItemAction ();
				break;
			case "deleteItem":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "showPedigree":
//			die ('xxx');
//				$_SESSION['genealogyTree']='Pedigree';
				$this->renderObjects = 
					$this->personServices->getPedigree ($this->getUserName(), $this->itemId, 5); 
				$this->renderer = 'showPedigree';
//				$this->getShowItemsParameters ();
				break;
			case "setYahooTree":
				$_SESSION['genealogyTree']='Yahoo';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['genealogyTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
			case "sort":
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->sortAction ($field, $order);
				//$this->getShowItemsParameters ();
				break;
			case "showLastNamesForCharacter":
				$this->renderObjects = $personServices->getPersonsForCharacter($_GET['character']);
				break;
			case "showPerson":
				$this->modifyAction ();
				$this->renderObjects = $this->personServices->getItemWithRelationShipsAndInformation($this->getUserName(), $_GET['itemId']);
				$this->renderer = 'showPerson';
				break;
			default:
				//die (print_r ($this->getDictionary()));
				$this->getShowItemsParameters ();
				break;
		}
	}

	function informationMode ()
	{
		$this->itemName="Information";
		$this->operations = new InformationServices ();
		$this->itemFactory = new InformationFactory ();
	}
	
	function personMode ()
	{
		$this->itemName="Person";
		$this->operations = new PersonServices ();
		$this->itemFactory = new PersonFactory ();
	}
}
//$controller = new GenealogyController ();
//$controller -> activate ();
//$controller -> display ();
?>
