<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is release under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/model/Item.php');
require_once ('plugins/genealogy/model/PersonServices.php');
/**
 * The Person item, part of the genealogy plugin
 *
 * @author Barry Nauta
 * @date January 2004
 * @package be.nauta.booby.plugins.genealogy.model
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class Person extends Item
{
	var $personServices;
	
	var $firstName;
	var $surName;
	var $surNamePrefix;
	var $title;
	var $alias;
	var $gender;
	var $birthDayInMonth;
	var $birthMonth;
	var $birthYear;
	var $birthPlace;
	var $deathDayInMonth;
	var $deathMonth;
	var $deathYear;
	var $deathPlace;
	var $imageURL;
	var $parentId1;
	var $parentId2;
	
	var $information;
	var $otherRelationShips;

	var $parents;
	var $marriages;
	var $children;
	var $other;
	
	function Person ($theID, $theOwner, $theParentId, $parent,
	                $theName, $theDescription, $theVisibility, $theCategory,
			$theCreation, $theModified,
			$theParentId1, $theParentId2, $theFirstName, $theSurName, $theSurNamePrefix,
			$theTitle, $theAlias, $theGender, 
			$theBirthDayInMonth, $theBirthMonth, $theBirthYear, $theBirthPlace,
			$theDeathDayInMonth, $theDeathMonth, $theDeathYear, $theDeathPlace,
			$theImageURL)

	{
		parent :: Item ($theID, $theOwner, $theParentId, $parent,
				$theName, $theDescription, $theVisibility,
				$theCategory, $theCreation, $theModified);
		$this->type="Person";
		$this->parentId1= $theParentId1;
		$this->parentId2= $theParentId2;
		$this->firstName = $theFirstName;
		$this->surName = $theSurName;
		$this->surNamePrefix = $theSurNamePrefix;
		$this->title=$theTitle;
		$this->alias=$theAlias;
		$this->gender=$theGender;
		$this->birthDayInMonth=$theBirthDayInMonth;
		$this->birthMonth=$theBirthMonth;
		$this->birthYear=$theBirthYear;
		$this->birthPlace=$theBirthPlace;
		$this->deathDayInMonth=$theDeathDayInMonth;
		$this->deathMonth=$theDeathMonth;
		$this->deathYear=$theDeathYear;
		$this->deathPlace=$theDeathPlace;
		$this->imageURL = $theImageURL;
		$this->personServices = new PersonServices ();
		
		$this->information = array ();
		$this->otherRelationShips = array ();
		
		$this->parents = array ();
		$this->children = array ();
		$this->marriages = array ();
	}
	/**
	 * Returns a human readable presentation of this item
	 *
 	 * @return string a human readable presentation of this item.
	 */
	function toString ()
	{
		$result  = '[Person]';
	 	$result .= ' ItemId:' . $this->itemId;
	 	$result .= ' ParentId:' . $this->parentId;
	 	$result .= ' Owner:' . $this->owner;
	 	$result .= ' Name:' . $this->name;
	 	$result .= ' Creation:' . $this->creation;
	 	$result .= ' Description:' . $this->description;
	 	$result .= ' Visibility:' . $this->visibility;
	 	$result .= ' IsParent:' . $this->isParent;
	 	$result .= ' #children: ' . count($this->children);
		return $result;
	}
	
	/**
	 * Checks whether the constructed item is a valid item (has all the
	 * required fields)
	 *
	 * @return boolean true if the item is valid, false otherwise
	 */	
	function isValid ()
	{
		if (!$this->isParent ())
		{
			return parent::isValid ();
		}
		return parent::isValid ();
	}
	
	function addInformation ($userId, $theInformationItem)
	{
		$this->information [] = $theInformationItem;
	}

	function addRelationShip ($userId, $theRelationShip)
	{
		if ($theRelationShip->theType=='ParentChild')
		{	
			if ($theRelationShip->person1 == $this->itemId)
			{
				$this->children [] = $this->personServices->getItem ($userId, $theRelationShip->person2); 
			}
			else if ($theRelationShip->person2 == $this->itemId)
			{
				$this->parents [] = $this->personServices->getItem ($userId, $theRelationShip->person1); 
			}
			else
			{
				die ("Invalid parentChild relationship");
			}
		}
		else if ($theRelationShip->theType='Marriage')
		{
			if ($theRelationShip->person1 == $this->itemId)
			{
				$this->marriages [] = $this->personServices->getItem ($userId, $theRelationShip->person2);
			}
			else
			{
				$this->marriages [] = $this->personServices->getItem ($userId, $theRelationShip->person1);
			}
		}
		else
		{
			$this->otherRelationShips [] = $theRelationShip;
		}
	}
}
?>
