
<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is release under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('plugins/genealogy/model/Person.php');
require_once ('plugins/genealogy/model/PersonFactory.php');
require_once ('plugins/genealogy/model/RelationShipServices.php');
require_once ('base/model/InformationServices.php');
require_once ('base/model/Services.php');
/**
 * Person operations. The BusinessLogic operations 
 *
 * @author Barry Nauta
 * @date January 2004
 * @package be.nauta.booby.plugins.genealogy.model
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class PersonServices extends Services
{
	/**
	 * Default constructor
	 */
	function PersonServices ()
	{
		parent :: Services ();
		$this->itemFactory = new PersonFactory ();
		
		include ('plugins/genealogy/sql/personQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds a person
	 * 
	 * @param integer userId the identifier for the user
	 * @param object item the item to be added
	 *
     * @return integer last know id. This is the id of the contact
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem ($userId, $item)
	{
//die ($item->description);
 //       if ($_SESSION['username'] != $userId) { return null; }

        global $db;

		$now = date ("Y-m-d H:i:s");
		$query  = sprintf ($this->queries['addItem'],
			$userId, 
			addslashes ($item->parentId), 
			addslashes ($item->isParent), 
			addslashes ($item->name), 
			addslashes ($item->description),
			addslashes ($item->visibility), 
			addslashes ($item->category), 
			addslashes ($now),
			addslashes ($item->parentId1), 
			addslashes ($item->parentId2), 
			addslashes ($item->firstName), 
			addslashes ($item->surName), 
			addslashes ($item->surNamePrefix), 
			addslashes ($item->title), 
			addslashes ($item->alias), 
			addslashes ($item->gender),
			addslashes ($item->birthDayInMonth), 
			addslashes ($item->birthMonth), 
			addslashes ($item->birthYear), 
			addslashes ($item->birthPlace),
			addslashes ($item->deathDayInMonth), 
			addslashes ($item->deathMonth), 
			addslashes ($item->deathYear), 
			addslashes ($item->deathPlace),
			addslashes ($item->imageURL));
		$result = $db->Execute($query) 
			or die("Add: " . $db->ErrorMsg() . " " . $query);
	}

	/**
	 * Modifies a person.
	 *
 	 * @param integer userId the identifier for the user who modifies a note
	 * @param object item the modified note
	 * @todo reestablish username/userId check
	 */
	function modifyItem ($userId, $item)
	{
//        if ($_SESSION['username'] != $userId) { die ($_SESSION['username'] . '*'.$userId);return null; }
		$this->checkOwner ($userId, $item->itemId);
//die (print_r ($item));
        global $db;
		$now = date ("Y-m-d H:i:s");

//die ($item->description);
		$query  = sprintf ($this->queries['modifyItem'], 
			$now, 
			addslashes ($item->name), 
			addslashes ($item->description), 
			addslashes ($item->parentId),
			addslashes ($item->parentId1), 
			addslashes ($item->parentId2), 
			addslashes ($item->firstName), 
			addslashes ($item->surName), 
			addslashes ($item->surNamePrefix), 
			addslashes ($item->title), 
			addslashes ($item->alias), 
			addslashes ($item->gender),
			addslashes ($item->birthDayInMonth), 
			addslashes ($item->birthMonth), 
			addslashes ($item->birthYear), 
			addslashes ($item->birthPlace),
			addslashes ($item->deathDayInMonth), 
			addslashes ($item->deathMonth), 
			addslashes ($item->deathYear), 
			addslashes ($item->deathPlace),
			addslashes ($item->imageURL), 
			$item->itemId) ;
//die ($query);
		$result = $db->Execute($query) 
			or die("Modify: " . $db->ErrorMsg() . " " . $query);
	}

	/**
	 * Gets a specific person for a user
	 *
	 * @param string userId the identifier for the user
	 * @param string itemId the identifier for the item
	 * @return object the item for specified user with specified itemId  
	 */
	function getItemWithRelationShipsAndInformation ($userId, $itemId)
	{
		$person = parent::getItem ($userId, $itemId);
		$informationServices = new InformationServices ();
		$relationShipServices = new RelationShipServices ();
		
		// Retrieve all information items related to this person
		$information = $informationServices->getItems ($userId, $person->itemId, 'PERSON');
		if ($information != null)
		{
			foreach ($information as $inf)
			{
				$person->addInformation ($userId, $inf);
			}
		}

		// Retrieve all relationship items related to this person
		$relationShips = $relationShipServices->getItem ($userId, $person->itemId);
		if ($relationShips != null)
		{
			foreach ($relationShips as $relationShip)
			{
				$person->addRelationShip ($userId, $relationShip);
			}
		}
		return $person;
	}
	
	/**
	 * Gets the pedigree of a certian person, limited to the depth (indicating max. number
	 * of ancestors we would like to process for the moment)
	 */
	function getPedigree ($userId, $personId, $depth)
	{
		$person = $this->getItem ($userId, $personId);
		if ($depth > 0)
		{
			$parent1 = $this->getPedigree ($userId, $person->parentId1, $depth-1);
			$parent2 = $this->getPedigree ($userId, $person->parentId2, $depth-1);
			
			$person->parents[]=$parent1;
			$person->parents[]=$parent2;
		}
		return $person;
		//die (print_r ($person));
	}
}
?>
