<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
include_once ("base/util/StringUtils.php");
/**
 * Used in combination with the Tree class
 *
 * @author Barry Nauta January 2004
 * @package be.nauta.booby.plugins.genealogy.view
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta <br />
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class PersonYahooTreeDelegate 
{
	/**
	 * String utilities
	 * @private
	 * @variable object stringUtils
	 */
	var $stringUtils;
	
	/**
	 * Icons in an hashtable. The icons must have the following keys:
	 * 'bar', 'up', 'minus', 'folder_open', 'corner', 'plus', 'tee',
	 * 'folder_closed', 'node', 'before_display', 'after_display'
	 * @private
	 * @variable hashtable icons
	 */
	var $icons;
	
	/**
	 * The URL to the callback, typically the controller
	 * @private
	 * @variable string callbackURL
	 */
	var $callbackURL;
	
	/**
	 * The dictionary that is used
	 * @private
	 * @variable array dictionary
	 */
	var $dictionary;

	/**
	 * Default constructor
	 * @param array theIcons the icons used for display
	 * @param string theCallbackURL
	 */
	function PersonYahooTreeDelegate 
		($theIcons, $theCallbackURL, $theDictionary)
	{
		$this->icons = $theIcons;
		$this->stringUtils = new StringUtils ();
		$this->dictionary = $theDictionary;
		$this->callbackURL = $theCallbackURL;
		
		$this->icons['chart']='<img src="plugins/genealogy/view/pics/chart.png" border="0">';
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		// Enable the overlib javascript popups
		$resultString = '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div><script language="JavaScript" src="base/view/javascript/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>';
		if ($item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->callbackURL;
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->icons['up'];
			$resultString .= '</a><br />';
		}
		
		$resultString .= '<table>';
		$resultString .= '<tr>';
		
		foreach ($this->dictionary['alphabet'] as $character)
		{
			$resultString .= '<td>';
			$resultString .= '<font size="+1">';
			$resultString .= '<button><a href="'.$this->callbackURL;
			$resultString .= '?action=showLastNamesForCharacter&character='.$character;
			$resultString .= '">'.$character.'</a></button>';
			$resultString .= '</font>';
			$resultString .= '</td>';
			
		}
		$resultString .= '</tr>';
		$resultString .= '</table>';
		return $resultString;
	}
	
	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString .= '<a href="';
		$resultString .= $this->callbackURL;
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->icons ['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->callbackURL;
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';
		
		$resultString .= '<br />';
		return $resultString;
	}
	
	
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		
		$resultString = '<table border="0" valign="top" width="220" bgcolor="#bbbbbb">';


		$resultString .= '<tr>';
		$resultString .= '<td class="menu" align="left" width="40">';
		$resultString .= '<a ';
		$resultString .= 'href="'.$this->callbackURL.'?itemId='.$item->itemId.'&action=modifyPersonPre"';
		$resultString .= '>'.$this->icons['edit'].'</a>';
		//$resultString .= '<a ';
		//$resultString .= 'href="'.$this->callBackURL.'?itemId='.$item->itemId.'&action=deletePerson"';
		//$resultString .= '>'.$this->icons['delete'].'</a>';
		$resultString .= '<a ';
		$resultString .= 'href="'.$this->callbackURL.'?itemId='.$item->itemId.'&action=showPedigree"';
		$resultString .= '>'.$this->icons['chart'].'</a>';
		$resultString .= '</td>';
		
		$resultString .= '<td class="menu"><b>';
		$resultString .= '<a href="'.$this->callbackURL.'?itemId='.$item->itemId.'&action=showPerson"';		
		$resultString .= $this->getPopupInformation ($item);
		$resultString .= '>';		
		$resultString .= $this->stringUtils->truncate($item->name, 20);
		$resultString .= '</a>';
		$resultString .= '</b>';
		$resultString .= '</td>';
		
		$resultString .= '</tr>';
				
		// Birth date
		$resultString .= '<tr>';		
		$resultString .= '<td class="contact">';
		$resultString .= $this->dictionary['birthDate'];
		$resultString .= '</td>';
		$resultString .= '<td class="contact">';
		$resultString .= $item->birthDayInMonth.'/'.$item->birthMonth.'/'.$item->birthYear;
		$resultString .= '</td>';
		$resultString .= '</tr>';

		// Death date		
		$resultString .= '<tr>';		
		$resultString .= '<td class="contact">';
		$resultString .= $this->dictionary['deathDate'];
		$resultString .= '</td>';
		$resultString .= '<td class="contact">';
		$resultString .= $item->deathDayInMonth.'/'.$item->deathMonth.'/'.$item->deathYear;
		$resultString .= '</td>';
		$resultString .= '</tr>';
		
		// alias
		if ($item->alias != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->dictionary['alias'];
			$resultString .= ':</td>';
			$resultString .= '<td class="contact">';
			$resultString .= $this->stringUtils->truncate ($item->alias, 20).'</a>';
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		if ($item->description != null)
		{
			$resultString .= '<tr>';
			$resultString .= '<td colspan="2" bgcolor="#ffffff">';
			$resultString .= $this->stringUtils->truncate ($item->description, 30);
			$resultString .= '</td>';
			$resultString .= '</tr>';
		}
		$resultString .= "<tr><td></td><td></td></tr>";
		$resultString .= '</table>';

		return $resultString;
	}
	
	function getPopupInformation ($item)
	{
		$resultString = '';
		// overlib popup
		$resultString .= 'onmouseover="return overlib(\'';
		$resultString .= '<table>';
		$resultString .= '<tr>';
		if ($item->imageURL != null)
		{
			$resultString .= '<td>';
			// Hmmm.... there appears to be a small problem with the quotes here...
			$resultString .= '<img src='.$item->imageURL.'>';
			$resultString .= '</td>';
		}
		$resultString .= '<td>';
		$resultString .= 'b.&nbsp;'.$item->birthDayInMonth.'/'.$item->birthMonth.'/'.$item->birthYear.'<br />';
		$resultString .= 'Place: '.$item->birthPlace.'<br />'; 
		$resultString .= 'd.&nbsp;'.$item->deathDayInMonth.'/'.$item->deathMonth.'/'.$item->deathYear.'<br />'; 
		$resultString .= 'Place: '.$item->deathPlace.'<br />'; 
		$resultString .= '</td>';
		
		$resultString .= '\', CAPTION, \'';
		$resultString .= $this->stringUtils->gpcAddSlashes($this->stringUtils->urlEncode($item->name)) . '\');" ';
		$resultString .= 'onmouseout="return nd();"';
		// end overlib popup
		
		
		return $resultString;
	}	
}
?>
