<?php
/**
 * vim: set tabstop=4 :
 * vim: set number :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Boby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('plugins/news/util/NewsUtils.php');
require_once ('plugins/news/model/NewsServices.php');
require_once ('plugins/news/model/NewsFactory.php');
require_once ('plugins/news/model/NewsPreferences.php');

require_class ('RightsManagerImpl', 'plugins/news/RightsManagerImpl.php'); // added by Michael
require_class ('RequestCast', 'base/util/request/RequestCast.class.php'); // added by Michael
/**
 * The News Controller
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.news
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class NewsController extends ItemController
{
	/**
	 * Constructor. 
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function NewsController ()
	{
		parent::ItemController ();
		$this->operations = new NewsServices ();
		$this->preferences = new NewsPreferences ();
		$this->itemFactory = new NewsFactory ();

		$this->rightsManager = new RightsManagerImpl(); 

		$this->pluginName = 'news';
		$this->title = 'Booby - News';
		$this->itemName = 'RSS';

		$this->expandName = 'newsExpand';
	}

	/**
 	 * Returns the actions defined for this item only
 	 * Modified by Michael : added navigationMode and rightsmanagement
 	 *
 	 * @return array an array of item specific actions (like search, 
	 * import etc.)
 	 */
	function getActions ()
	{
		$dictionary = $this->getDictionary ();
	
		/*
	 	 * Actions
		 */
		$actions[0]['name'] = $dictionary['actions'];
		
		if($this->rightsManager->isGranted($this->getParentId (), "add"))
			$actions[0]['contents'][] = array(
				'href' => 'NewsController.php?action=add&parentId='.
					$this->getParentId (),
				'name' => $dictionary['add']
				);
		/* This works in my version with 1 template file, if you are interested, tell me. (Michael)
		if($this->rightsManager->isGranted($this->getParentId (), "addFolder"))
			$actions[0]['contents'][] = array(
				'href' => 'NewsController.php?action=add&isParent=1&parentId='.$this->getParentId (),
				'name' => $dictionary['addFolder']
				);
				
		if($this->rightsManager->isGranted($this->getParentId (), "addNode"))
			$actions[0]['contents'][] = array(
				'href' => 'NewsController.php?action=add&isParent=0&parentId='.$this->getParentId (),
				'name' => $dictionary['addNode']
				);
		*/
		if($this->rightsManager->isGranted($this->getParentId (), 
			"multipleSelectPre"))
			$actions[0]['contents'][] = array(
				'href' => 'NewsController.php?action=multipleSelectPre&parentId='.$this->getParentId(),
				'name' => 'Multiple Select'
				);
			
		if($this->rightsManager->isGranted($this->getParentId (), 
			"import"))		
			$actions[0]['contents'][] = array(
				'href' => 'NewsController.php?action=import',
				'name' => $dictionary['import']
				);
				
		if($this->rightsManager->isGranted($this->getParentId (), 
			"export"))		
			$actions[0]['contents'][] = array(
				'href' => 'NewsController.php?action=export',
				'name' => $dictionary['export']
				);
			
		if($this->rightsManager->isGranted($this->getParentId (), 
			"search"))		
			$actions[0]['contents'][] = array(
				'href' => 'NewsController.php?action=search',
				'name' => $dictionary['search']
				);
		
		/*
		 * Views
		 */
		$actions[1]['name'] = $dictionary['view'];
		if($this->rightsManager->isGranted($this->getParentId (), "view"))
		{
			$actions[1]['contents'][] = array('href' => 'NewsController.php?expand=*',
			'name' => $dictionary['expand']);
			$actions[1]['contents'][] = array('href' => 'NewsController.php?expand=0',
			'name' => $dictionary['collapse']);
			$actions[1]['contents'][] = array('href' => 'NewsController.php?action=setYahooTree&parentId='.$this->getParentId (),
			'name' => $dictionary['yahooTree']);
			$actions[1]['contents'][] = array('href' => 'NewsController.php?action=setExplorerTree&parentId='.$this->getParentId (),
			'name' => $dictionary['explorerTree']);
			$actions[1]['contents'][] = array('href' => 'NewsController.php?action=setModePublic&parentId='.$this->getParentId (),
			'name' => $dictionary['setModePublic']);
			$actions[1]['contents'][] = array('href' => 'NewsController.php?action=setModePrivate&parentId='.$this->getParentId (),
			'name' => $dictionary['setModePrivate']);
		}
				
		/*
		 * Sort
		 */
		$actions[2]['name'] = $dictionary['sort'];
		if($this->rightsManager->isGranted($this->getParentId (), "sort"))
		{
			$actions[2]['contents'][] = array('href'=> 'NewsController.php?action=sort&order=DESC&field=when_visited',
			'name' => $dictionary['last_visited']);
			$actions[2]['contents'][] = array('href'=> 'NewsController.php?action=sort&order=DESC&field=visitCount',
			'name' => $dictionary['most_visited']);
			$actions[2]['contents'][] = array('href'=> 'NewsController.php?action=sort&order=DESC&field=when_created',
			'name' => $dictionary['last_created']);
			$actions[2]['contents'][] = array('href'=> 'NewsController.php?action=sort&order=DESC&field=when_modified',
			'name' => $dictionary['last_modified']);
			
		}
		
		/*
		 * Preferences
		 */		
		if($this->rightsManager->isGranted($this->getParentId (), "preferences"))
		{
			$actions[3]['name'] = $dictionary['preferences'];
			$actions[3]['contents'][] = array('href'=> 'NewsController.php?action=modifyPreferencesPre',
			'name' => $dictionary['modify']);
		}
		
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "add":
				$this->directAction ($this->getAction ());
//				$this->addAction ();
				break;
			// this is to show an Item in a special showItem Page
			case "showItem":
				$this->directAction ($this->getAction (), true);
				break;
			case "addItem":
				$this->addItemAction ();
				break;
			case "modify":
				$this->modifyAction ();
				break;
			case "modifyItem":
				$this->modifyItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode. If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "import":
			case "export":
			case "search":
				$this->renderer = $this->getAction ().'News';
				break;
			case "searchItems":
				$this->searchItemAction ();
				break;
			case "multipleSelectPre":
				$_SESSION['newsExpand']= '*';
				$this->multipleSelectAction ();
				break;
			case "multipleSelectPost":
				$itemIds = array_keys ($_POST, "itemId");
				if (isset ($_POST['move']))
				{
					$this->moveMultipleAction ($itemIds);
				}
				else if (isset ($_POST['delete']))
				{
					foreach ($itemIds as $itemId)
					{
						$this->operations->deleteItem ($this->getUserName (), $itemId);
					}
					$this->getShowItemsParameters ();
				}
				break;
                        case "moveMultipleItemsPost":
				$itemIds = explode (",", $_GET['itemIds']);
				$parentId = $_GET['parentId'];
				foreach ($itemIds as $itemId)
				{
					$this->operations->moveItem ($this->getUserName (), $itemId, $parentId);
				}
				$this->getShowItemsParameters ();
				break;
			case "deleteItem":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "showItem":
				$this->operations->updateVisiteCount ($this->getUserName(), $this->itemId);
				$bookmark = $this->operations->getItem
					($this->getUserName(), $this->itemId);
				header ("Location: " . $bookmark->locator);
   				exit;
				break;
			case "importNews":
				$newsUtils = new NewsUtils ();
				// first set the execution time to zero: unlimited.
				// Not that this has no effect if safe_mode is on
				set_time_limit (0);

		        $importType=$_POST['importType'];
		        $parentId = $_POST['parentId'];
		   		$importFile = $_FILES['importFile'];
		   		if ($importType == 'Opera')
		        {
		                $newsUtils->importOperaBookmarks
		                	($this->getUserName (), $importFile['tmp_name'], $this, $parentId);
		        }
				else if ($importType == 'Netscape')
				{
		                $newsUtils->importNetscapeBookmarks
		                	($this->getUserName (), $importFile['tmp_name'], $this, $parentId);
				}
		        else
		        {
		                die ($importType . " is not yet supported for importing bookmarks");
		        }
		        $this->getShowItemsParameters ();
		        // We need to force a redirection to this page, otherwise a reload means
		        // resending the POST data and your items will be imported twice
		        header ("Location: NewsController.php");
		        exit ();
				break;
			case "exportBookmarks":
				$newsUtils = new NewsUtils ();
			    $exportType=$_POST['exportType'];
			    $parentId = $_POST['parentId'];
			    if ($exportType == 'Opera')
				{
					Header ("Content-type: text/plain");
					echo ("Opera Hotlist version 2.0\n\n");

					$newsUtils->exportOperaBookmarks
						($this->getUserName (), $parentId, $this);
					exit ();
				}
				else if ($exportType == 'Netscape')
				{
					Header ("Content-type: text/plain");
					$newsUtils->exportNetscapeBookmarks
						($this->getUserName (), $parentId, $this);
					exit ();
				}
				break;
			case "setYahooTree":
				$_SESSION['newsTree']='Yahoo';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['newsTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects = 
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['newsTree']=
					$this->preferences->getPreferenceValue ($this->getUserName (), 'newsTree');
				$_SESSION['newsOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsOverlib');
				$_SESSION['newsYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsYahooTreeColumnCount');
					$_SESSION['newsNewWindowTarget']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsNewWindowTarget');
				$this->getShowItemsParameters ();
				break;
			default:
				if (!isset ($_SESSION['newsTree']))
				{
					$_SESSION['newsTree']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsTree');
				}
				if (!isset ($_SESSION['newsOverlib']))
				{
					$_SESSION['newsOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsOverlib');
				}
				if (!isset ($_SESSION['newsYahooTreeColumnCount']))
				{
					$_SESSION['newsYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsYahooTreeColumnCount');
				}
				if (!isset ($_SESSION['newsNewWindowTarget']))
				{
					$_SESSION['newsNewWindowTarget']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsNewWindowTarget');
				}
				$this->getShowItemsParameters ();
				break;
		}
	}

}
//$controller = new NewsController ();
//$controller -> activate ();
//$controller -> display ();
?>
