<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ('base/view/TreeDelegate.php');
require_once ("plugins/news/util/magpierss/rss_fetch.inc");
require_once ("plugins/news/util/magpierss/rss_parse.inc");
/**
 * Used in combination with the PHPItemTree class
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.news.view
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class NewsExplorerTreeDelegate extends TreeDelegate
{
	/**
	 * Default constructor
	 */
	function NewsExplorerTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div><script language="JavaScript" src="base/view/javascript/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>';

		if ($item->itemId == 0)
		{
			$resultString .= $this->configuration['icons']['root'];
		}
		else
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a>';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';

		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}

		if ($isExpanded)
		{
			$res = $tree->createExpandedListWithout ($item->itemId);
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?expand=' . implode (',', $res);
			$resultString .= '&parentId='.$tree->root->itemId;
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['minus'];
			$resultString.= '</a>';

			$resultString.= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['folder_open'];
			$resultString .= '</a>';
		}
		else
		{
			// ???
			$linkExpand = "";
			// ???
			if (!$tree->isExpanded ($item->itemId) && $tree->expanded != null)
			{
				$linkExpand .= implode(",", $tree->expanded).",".$item->itemId;
			}
			else
			{
				$linkExpand = $item->itemId;
			}
			if ($item->parentId != null)
			{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '?expand=' . $linkExpand;
				$resultString .= '">';
			}
			else
			{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '?expand='.$linkExpand.'">';
			}
			$resultString .= $this->configuration['icons'] ['plus'];
			$resultString .= '</a>';
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons'] ['folder_closed'];
			$resultString .= '</a>';
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '</td></tr>';
		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}
		if ($lastNode)
		{
			$resultString .= $this->configuration['icons']['corner'];
		}
		else
		{
			$resultString .= $this->configuration['icons']['tee'];
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['node'];
		$resultString .= '</a>';

		// testing purposes. Developing on a local machine might imply that
		// you are being blocked by a proxy. Magpie does not provide
		// proxy things, so you can test by loading a file that is something
		// in the form of either file:///c:/temp/myfile.xml or
		// file:///home/barrel/tmp/myfile.xml
		//
		// Local file MUST start with 'file:///'
		if ($this->stringUtils->startsWith ($item->locator, "file:///"))
		{
			$filename = substr($item->locator, strlen("file:///"), strlen ($item->locator));
			$fh = fopen($filename, 'r') or die($php_errormsg);
    		$rss_string = fread($fh, filesize($filename) );
    		fclose($fh);
    		$rss = new MagpieRSS ($rss_string);
		}
		else
		{
			$rss = fetch_rss ($item->locator);
		}
		if ($rss)
		{
			$rssFeed  = '<table>';

			// Only show the image if an image URL is provided
			if ($rss->image['url'] != null)
			{
				$rssFeed .= '<tr><td bgcolor=#ffffff>';
				$rssFeed .= '<img src='.$rss->image['url'].' border=0>';
				$rssFeed .= '</td></tr>';
			}

			$rssFeed .= '<tr><td>';
			foreach ($rss->items as $rssitem)
			{
				$rssFeed .= '<table>';
				$rssFeed .= '<tr><td><b>';
				$rssFeed .= $this->stringUtils->urlEncode ($rssitem['title']);
				$rssFeed .= '</b></td></tr>';
				$rssFeed .= '<tr><td>';
				$rssFeed .= $this->stringUtils->urlEncode ($rssitem['description']);
				$rssFeed .= '</td></tr>';
				$rssFeed .= '</table>';

			}
			$rssFeed .= '</td></tr>';
			$rssFeed .= '</table>';

			$resultString .= "<a href='".$rss->channel['link']."' ";
			
			if ($this->configuration['overlib'])
			{
				$resultString .= $this->overLib ($item->name, $item->description);
			}			
			if (isset ($this->configuration['newsNewWindowTarget']) &&
				($this->configuration['newsNewWindowTarget'] == '_blank')
				)
			{
				$resultString .= ' target="'.$this->configuration['newsNewWindowTarget'].'" ';
			}

			$resultString .= 'alt="'. $item->name;
			$resultString .= '" >'.$item->name.'</a>';
		}
		else
		{

			$resultString .= "<b>Error: </b>Could not parse ".$item->name;
		}
		// open in new window option
		/*
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=showItem&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['open_new_window'] . '</a>';
		*/

		$resultString .= '</td></tr>';
		return $resultString;
	}
}
?>
