<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ('base/view/TreeDelegate.php');
require_once ("plugins/news/util/magpierss/rss_fetch.inc");
require_once ("plugins/news/util/magpierss/rss_parse.inc");
/**
 * Used in combination with the Tree classes
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.news.view
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class NewsYahooTreeDelegate extends TreeDelegate
{
	/**
	 * Default constructor
	 * @param array theIcons the icons used for display
	 * @param string theCallbackURL
	 */
	function NewsYahooTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString ='';
		if ($item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons'] ['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		// testing purposes. Developing on a local machine might imply that
		// you are being blocked by a proxy. Magpie does not provide
		// proxy things, so you can test by loading a file that is something
		// in the form of either file:///c:/temp/myfile.xml or
		// file:///home/barrel/tmp/myfile.xml
		//
		// Local file MUST start with 'file:///'
		if ($this->stringUtils->startsWith ($item->locator, "file:///"))
		{
			$filename = substr($item->locator, strlen("file:///"), strlen ($item->locator));
			$fh = fopen($filename, 'r') or die($php_errormsg);
    		$rss_string = fread($fh, filesize($filename) );
    		fclose($fh);
    		$rss = new MagpieRSS ($rss_string);
		}
		else
		{
			$rss = fetch_rss ($item->locator);
		}
		if ($rss)
		{
			$resultString = '<table border="0" width="300">';

			// one row with name and icon to modify
			$resultString .= '<tr valign="top">';
			$resultString .= '<td><b>';
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['node'];
			$resultString .= '</a>';
			$resultString .= '<a href="';
			$resultString .= $rss->channel['link'];
			if (
				isset ($this->configuration['newsNewWindowTarget']) &&
				($this->configuration['newsNewWindowTarget'] == '_blank')
				)
			{
				$resultString .= ' target="'.$this->configuration['newsNewWindowTarget'].'" ';
			}
			$resultString .= '">';
			$resultString .= $item->name;
			$resultString .= '</a></b>';
			$resultString .= '</td>';
			$resultString .= '</tr>';

			$resultString .= '<tr>';
			$resultString .= '<td><em>';
			$resultString .= $rss->channel['description'];
			$resultString .= '</em></td>';
			$resultString .= '</tr>';

			// Only show the image if the image URL is provided
			if (isset ($rss->image['url']) && $rss->image['url'] != null)
			{
				$resultString .= '<tr>';
				$resultString .= '<td><img src="';
				$resultString .= $rss->image['url'];
				$resultString .= '"></td>';
				$resultString .= '</tr>';
			}
			foreach ($rss->items as $rssitem)
			{
				$resultString .= '<tr>';
				$resultString .= '<td>';
				$resultString .= '<a href="';
				$resultString .= $rssitem['link'];
				$resultString .= '">';
				$resultString .= $this->stringUtils->urlEncode ($rssitem['title']);
				$resultString .= '</a>';
				$resultString .= '</td>';
				$resultString .= '</tr>';

				if (isset ($rssitem['description']) && $rssitem['description']!= null)
				{
					$resultString .= '<tr>';
					$resultString .= '<td>';
					$resultString .= $this->stringUtils->urlEncode ($rssitem['description']);
					$resultString .= '</td>';
					$resultString .= '</tr>';
				}
			}

			$resultString .= '</table>';
		}
		else
		{
			$resultString = '<table border="0" width="300">';
			$resultString .= '<tr valign="top">';
			$resultString .= '<td><b>';
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['node'];
			$resultString .= '</a>';
			$resultString .= "<b>Error: </b>Could not parse ".$item->name;
			$resultString .= "</td></tr>";
			$resultString .= '</table>';

		}
		return $resultString;
	}
}
?>
