<?php
/*
 * vim: set tabstop=4 :
 * vim: set number :
 * 
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ('base/ItemController.php');
require_once ('plugins/notes/model/NoteServices.php');
require_once ('plugins/notes/model/NotePreferences.php');

require_class ('RightsManagerImpl', 'plugins/notes/RightsManagerImpl.php');
require_class ('RequestCast', 'base/util/request/RequestCast.class.php'); 
/**
 * The Note Controller
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.notes
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class NoteController extends ItemController
{
	/**
	 * Constructor. 
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function NoteController ()
	{
		parent::ItemController ();
		$this->operations = new NoteServices ();
		$this->preferences = new NotePreferences ();
		$this->itemFactory = new NoteFactory ();

		$this->rightsManager = new RightsManagerImpl(); 

		$this->pluginName = 'notes';
		$this->title = 'Booby - Notes';
		$this->itemName = 'Note';

		$this->expandName = 'noteExpand';
	}

	/**
	 * Returns the title of this Controller
	 *
	 * @return string the title of this controller
	 */
	function getTitle ()
	{
		return "Booby - Notes";
	}

	/**
	 * Returns the name of the item that is controller by this controller
	 *
	 * @return string the name of the item that is controlled by this controller
	 */
	function getItemName ()
	{
		return "Note";
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions (like search, import etc.)
 	 */
	function getActions ()
	{
		$dictionary = $this->getDictionary ();
		$actions=array();
		
		// Actions
		$actions[0]['name']= $dictionary['actions'];
		$actions[0]['contents'][]=
			array('href' => 'NoteController.php?action=add&parentId='.$this->getParentId (),
			'name' => $dictionary['add']);
		$actions[0]['contents'][]=
			array ('href'=>'NoteController.php?action=multipleSelectPre&parentId='.$this->getParentId(),
			'name'=>$dictionary['multipleSelect']);
		$actions[0]['contents'][]=
			array('href' => 'NoteController.php?action=search',
			'name' => $dictionary['search']);

		// View
		$actions[1]['name']= $dictionary['view'];
		$actions[1]['contents'][]=
			array('href' => 'NoteController.php?expand=*',
			'name' => $dictionary['expand']);
		$actions[1]['contents'][]=
			array('href' => 'NoteController.php?expand=0',
			'name' => $dictionary['collapse']);
		$actions[1]['contents'][]=
			array('href' => 'NoteController.php?action=setYahooTree&parentId='.$this->getParentId (),
			'name' => $dictionary['yahooTree']);
		$actions[1]['contents'][]=
			array('href' => 'NoteController.php?action=setExplorerTree&parentId='.$this->getParentId (),
			'name' => $dictionary['explorerTree']);
		$actions[1]['contents'][] = 
			array('href' => 'NoteController.php?action=setModePublic&parentId='.$this->getParentId (),
			'name' => $dictionary['setModePublic']);
		$actions[1]['contents'][] = 
			array('href' => 'NoteController.php?action=setModePrivate&parentId='.$this->getParentId (),
			'name' => $dictionary['setModePrivate']);

		// Preferences
		$actions[2]['name']= $dictionary['preferences'];
		$actions[2]['contents'][]=
			array ('href'=>'NoteController.php?action=modifyPreferencesPre',
			'name'=>$dictionary['modify']);
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions 
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "add":
				$this->renderer = 'addNote';
				break;
			case "modify":
				$this->renderer = 'modifyNote';
				$this->renderObjects =
					$this->operations->getItem ($this->getUserName(), $this->itemId);
				break;
			case "delete":
				$this->operations->deleteItem ($this->getUserName(), $this->itemId);
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode. If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "multipleSelectPre":
				$_SESSION['noteExpand']='*';
				$this->multipleSelectAction ();
				break;
			case "multipleSelectPost":
				$itemIds = array_keys ($_POST, "itemId");
				if (isset ($_POST['move']))
				{
					$this->moveMultipleAction ($itemIds);
				}
				else if (isset ($_POST['delete']))
				{
					foreach ($itemIds as $itemId)
					{
						$this->operations->deleteItem ($this->getUserName (), $itemId);
					}
					$this->getShowItemsParameters ();
				}
				break;
			case "moveMultipleItemsPost":
				$itemIds = explode (",", $_GET['itemIds']);
				$parentId = $_GET['parentId'];
				foreach ($itemIds as $itemId)
				{
					$this->operations->moveItem ($this->getUserName (), $itemId, $parentId);
				}
				$this->getShowItemsParameters ();
				break;
			case "searchNotes":
				$this->searchItemAction();
				break;
			case "search":
				$this->renderer = $this->getAction().'Notes';
				break;
			case "addNote":
				$this->addItemAction();
				$this->getShowItemsParameters ();
				break;
			case "modifyNote":
				$this->modifyItemAction();
				$this->getShowItemsParameters ();
				break;
			case "setYahooTree":
				$_SESSION['noteTree']='Yahoo';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['noteTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects = 
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['noteTree']=
					$this->preferences->getPreferenceValue ($this->getUserName (), 'noteTree');
				$_SESSION['noteOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'noteOverlib');
				$_SESSION['noteYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'noteYahooTreeColumnCount');
				$this->getShowItemsParameters ();
				break;
			default:
				if (!isset ($_SESSION['noteTree']))
				{
					$_SESSION['noteTree']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'noteTree');
				}
				if (!isset ($_SESSION['noteOverlib']))
				{
					$_SESSION['noteOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'noteOverlib');
				}
				if (!isset ($_SESSION['noteYahooTreeColumnCount']))
				{
					$_SESSION['noteYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'noteYahooTreeColumnCount');
				}
				$this->getShowItemsParameters ();
				break;
			}
	}

}
//$controller = new NoteController ();
//$controller -> activate ();
//$controller -> display ();
?>
