<?php
/**
 * vim: set tabstop=4 :
 * vim: set number :
 *
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/ItemController.php");
require_once ("plugins/todos/model/Todo.php");
require_once ("plugins/todos/model/TodoFactory.php");
require_once ("plugins/todos/model/TodoServices.php");
require_once ('plugins/todos/model/TodoPreferences.php');

require_class ('RightsManagerImpl', 'plugins/todos/RightsManagerImpl.php'); 
require_class ('RequestCast', 'base/util/request/RequestCast.class.php'); 
/**
 * The Todo Controller
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.todos
 * @copyright
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code>
 * and look for licenses
 */
class TodoController extends ItemController
{
	/**
	 * Constructor. 
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function TodoController ()
	{
		parent::ItemController ();
		$this->operations = new TodoServices ();
		$this->preferences = new TodoPreferences ();
		$this->itemFactory = new TodoFactory ();

		$this->rightsManager = new RightsManagerImpl(); 

		$this->pluginName = 'todos';
		$this->title = 'Booby - Todo';
		$this->itemName = 'Todo';

		$this->expandName = 'todoExpand';
	}

	/**
	 * Returns the title of this Controller
	 *
	 * @return string the title of this controller
	 */
	function getTitle ()
	{
		return "Booby - Todos";
	}

	/**
	 * Returns the name of the item that is controller by this controller
	 *
	 * @return string the name of the item that is controlled by this controller
	 */
	function getItemName ()
	{
		return "Todo";
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions (like search, import etc.)
 	 */
	function getActions ()
	{
		$dictionary = $this->getDictionary ();
		$actions=array();
		
		/* 
		 * Actions
		 */
		$actions[0]['name']=$dictionary['actions']; 
		$actions[0]['contents'][]=
			array('href' => 'TodoController.php?action=add&parentId='.$this->getParentId(),
			'name' => $dictionary['add']);
		$actions[0]['contents'][]=
			array('href' => 'TodoController.php?action=multipleSelectPre&parentId='.$this->getParentId(),
			'name'=> $dictionary['multipleSelect']);
		$actions[0]['contents'][]=
			array('href' => 'TodoController.php?action=search',
			'name' => $dictionary['search']);



		/*
		 * View
		 */
		$actions[1]['name']=$dictionary['view'];
		$actions[1]['contents'][]=
					array('href' => 'TodoController.php?expand=*',
						'name' => $dictionary['expand']);
		$actions[1]['contents'][]=
					array('href' => 'TodoController.php?expand=0',
						'name' => $dictionary['collapse']);
		$actions[1]['contents'][]=
					array('href' => 'TodoController.php?action=setYahooTree&parentId='.$this->getParentId (),
						'name' => $dictionary['yahooTree']);
		$actions[1]['contents'][]=
					array('href' => 'TodoController.php?action=setOverviewTree&parentId='.$this->getParentId (),
						'name' => $dictionary['overviewTree']);
		$actions[1]['contents'][]=
					array('href' => 'TodoController.php?action=setLineBasedTree&parentId='.$this->getParentId (),
						'name' => $dictionary['lineBasedTree']);
		$actions[1]['contents'][]=
					array('href' => 'TodoController.php?action=setExplorerTree&parentId='.$this->getParentId (),
						'name' => $dictionary['explorerTree']);
		$actions[1]['contents'][] = 
					array('href' => 'TodoController.php?action=setModePublic&parentId='.$this->getParentId (),
						'name' => $dictionary['setModePublic']);
		$actions[1]['contents'][] = 
					array('href' => 'TodoController.php?action=setModePrivate&parentId='.$this->getParentId (),
						'name' => $dictionary['setModePrivate']);

		/*
		 * Sort
		 */
		$actions[2]['name']=$dictionary['sort'];
		$actions[2]['contents'][] = 
					array('href'=> 'TodoController.php?action=sort&order=ASC&field=priority', 
						'name' => $dictionary['priority']);
		$actions[2]['contents'][] = 
					array('href'=> 'TodoController.php?action=sort&order=DESC&field=percentComplete', 
						'name' => $dictionary['complete']);
		$actions[2]['contents'][] = 
					array('href'=> 'TodoController.php?action=sort&order=ASC&field=startDate', 
						'name' => $dictionary['start_date']);
		$actions[2]['contents'][] = 
					array('href'=> 'TodoController.php?action=sort&order=ASC&field=endDate', 
						'name' => $dictionary['due_date']);

		/*
		 * Preferences
		 */
		$actions[3]['name']=$dictionary['preferences'];
		$actions[3]['contents'][] = 
					array ('href'=>'TodoController.php?action=modifyPreferencesPre',
						'name'=>$dictionary['modify']);
			
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions are 
	 * executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "add":
				$this->renderer = 'addTodo';
				break;
			case "modify":
				$this->renderer = 'modifyTodo';
				$this->renderObjects =
					$this->operations->getItem 
						($this->getUserName(), $this->itemId);
				break;
			case "delete":
				$this->operations->deleteItem 
					($this->getUserName(), $this->itemId);
				// and show all items
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode. 
			// If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "searchTodos":
				    $this->renderObjects = 
						$this->operations->searchItems
         					($this->getUserName(), 
								$_POST['field'], $_POST['value']);
					$this->renderer = 'showTodos';
				break;
			case "search":
				$this->renderer = $this->getAction().'Todos';
				break;
			case "sort":
				$parentId = $_GET['parentId'];
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->sortAction ($parentId, $field, $order);
				break;
			case "modifyTodo":
				$this->operations->modifyItem($this->getUserName(),
					$this->itemFactory->requestToItem());
				// and show all items
				$this->getShowItemsParameters ();
				break;
			case "addTodo":
				$this->operations->addItem($this->getUserName(),
					$this->itemFactory->requestToItem ());
				// and show all items
				$this->getShowItemsParameters ();
				break;
			case "multipleSelectPre":
				$_SESSOPM['todoExpand']='*';
				$this->multipleSelectAction ();
				break;
			case "multipleSelectPost":
				$itemIds = array_keys ($_POST, "itemId");
				if (isset ($_POST['move']))
				{
					$this->moveMultipleAction ($itemIds);
				}				
				else if (isset ($_POST['delete']))
				{
					foreach ($itemIds as $itemId)
					{
						$this->operations->deleteItem 
							($this->getUserName (), $itemId);
					}
					$this->getShowItemsParameters ();
				}
				break;
			case "moveMultipleItemsPost":
				$parentId = $_GET['parentId'];
				$itemIds = explode (",", $_GET['itemIds']);
				foreach ($itemIds as $itemId)
				{
					$this->operations->moveItem ($this->getUserName (), 
						$itemId, $parentId);
				}
					$this->getShowItemsParameters ();
				break;
			case "setYahooTree":
				$_SESSION['todoTree']='Yahoo';
				$this->getShowItemsParameters ();
				break;
			case "setOverviewTree":
				$_SESSION['todoTree']='Overview';
				$this->getShowItemsParameters ();
				break;
			case "setLineBasedTree":
				$_SESSION['todoTree']='LineBased';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['todoTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects = 
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['todoTree']=
					$this->preferences->getPreferenceValue ($this->getUserName (), 'todoTree');
				$_SESSION['todoOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'todoOverlib');
				$_SESSION['todoYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'todoYahooTreeColumnCount');
				$this->getShowItemsParameters ();
				break;
			default:
				if (!isset ($_SESSION['todoTree']))
				{
					$_SESSION['todoTree']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'todoTree');
				}
				if (!isset ($_SESSION['todoOverlib']))
				{
					$_SESSION['todoOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'todoOverlib');
				}
				if (!isset ($_SESSION['todoYahooTreeColumnCount']))
				{
					$_SESSION['todoYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'todoYahooTreeColumnCount');
				}
				$this->getShowItemsParameters ();
				break;
			}
	}
}
//$controller = new TodoController ();
//$controller -> activate ();
//$controller -> display ();
?>
