<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ("base/view/TreeDelegate.php");
/**
 * Used in combination with the Tree classes
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.todos.view
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta 
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class TodoExplorerTreeDelegate extends TreeDelegate
{
	
	/**
	 * Default constructor
	 * @param array theConfiguration. This configuration must contain the following items:
	 * <ul>
	 * <li>icons. Icons in an hashtable. The icons must have the following keys:
	 * 	<ul>
	 			<li>'bar'</li>
	 			<li>'up'</li>
	 			<li>'minus'</li>
	 			<li>'folder_open'</li>
	 			<li>'corner'</li>
	 			<li>'plus'</li>
	 			<li>'tee'</li>
	 			<li>'folder_closed'</li>
	 			<li>'node'</li>
	 			<li>'before_display'</li>
	 			<li>'after_display'</li>
	 			<li>'add'</li>
	 			<li>'delete'</li>
	 			<li>'edit'</li>
	 			<li>'up_arrow_shaded'</li>
	 			<li>'up_arraw'</li>
	 			<li>'down_arrow'</li>
	 			<li>'down_arrow_shaded'</li>
	 		</ul>
	 * </li>
	 * <li>callback. The URL to the callback, typically the controller</li>
	 * <li>dictionairy. The dictionary that is used</li>
	 * </ul>
	 */
	function TodoExplorerTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div><script language="JavaScript" src="base/view/javascript/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>';

		if ($item->itemId == 0)
		{
			$resultString .= $this->configuration['icons']['root'];
		}
		else
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a>';
		}
		return $resultString;
	}
	
	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';
								
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}

		if ($item->isParent)
		{
			//die ("Is parent. Expanded?" . $isExpanded);
		}	
		if ($isExpanded)
		{

			$res = $tree->createExpandedListWithout ($item->itemId);
			
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?expand=' . implode (',', $res);
			$resultString .= '&parentId='.$tree->root->itemId;
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['minus'];
			$resultString.= '</a>';
			
			$resultString.= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['folder_open'];
			$resultString .= '</a>';
		}
		else
		{
			// ???
			$linkExpand = "";
			// ???
			if (!$tree->isExpanded ($item->itemId) && $tree->expanded != null)
			{
				$linkExpand .= implode(",", $tree->expanded).",".$item->itemId;
			}
			else
			{
				$linkExpand = $item->itemId;
			}
			if ($item->parentId != null)
			{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '?expand=' . $linkExpand;
				$resultString .= '">';
			}
			else
			{
				$resultString .= '<a href="';
				$resultString .= $this->callbackURL;
				$resultString .= '?expand='.$linkExpand.'">';
			}
			$resultString .= $this->configuration['icons']['plus'];
			$resultString .= '</a>';
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['folder_closed'];
			$resultString .= '</a>';
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';
		
		$resultString .= '</td></tr>';
		
		return $resultString;
	}
	
	
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}
		if ($lastNode)
		{
			$resultString .= $this->configuration['icons']['corner'];
		}	
		else
		{
			$resultString .= $this->configuration['icons']['tee'];
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['node'];
		$resultString .= '</a>';

		$resultString .= "<a href='";
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . "' ";


		if ($this->configuration['overlib'])
		{
			$resultString .= $this->overLib ($item->name, $item->description);
		}
		// overlib popup
		/*
		$resultString .= "onmouseover=\"return overlib('";
		$resultString .= $this->stringUtils->gpcAddSlashes ($this->stringUtils->urlEncode($item->description));
		$resultString .= "', CAPTION, '";
		$resultString .= $this->stringUtils->gpcAddSlashes($this->stringUtils->urlEncode($item->name)) . "');\" ";
		$resultString .= "onmouseout=\"return nd();\" ";
		*/
		// end overlib popup
	
		$resultString .= 'alt="'. $item->name . '" target=_new>';
		$resultString .= $item->name;
		$resultString .= '</a>';
	
		$resultString .= '</td></tr>';
		return $resultString;
	}	
}
?>
