<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ("base/view/TreeDelegate.php");
/**
 * Used in combination with the Tree class
 *
 * @author Barry Nauta January 2004
 * @package be.nauta.booby.plugins.todos.view
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class TodoOverviewTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function TodoOverviewTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div><script language="JavaScript" src="base/view/javascript/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>';

		if ($item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString .= '<h2>Root (id: 0)</h2>';
		}
		return $resultString;
	}
	
	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $identLevel)
	{
		if ($identLevel % 2 == 0)
		{
			$class = 'overviewTreeEven';
		}
		else
		{
			$class = 'overviewTreeOdd';
		}
		$resultString = '<table border="0" class="'.$class.'" width="100%">';
		$resultString .= '<tr class="'.$class.'"><td width="50">';
		if ($isExpanded)
		{
			$res = $tree->createExpandedListWithout ($item->itemId);
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?expand=' . implode (',', $res);
			$resultString .= '&parentId='.$tree->root->itemId;
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['overviewcollapse'];
			$resultString.= '</a>&nbsp;';

			$resultString.= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['folder_open'];
			$resultString .= '</a>';
		}
		else
		{
			// ???
			$linkExpand = "";
			// ???
			if (!$tree->isExpanded ($item->itemId) && $tree->expanded != null)
			{
				$linkExpand .= implode(",", $tree->expanded).",".$item->itemId;
			}
			else
			{
				$linkExpand = $item->itemId;
			}
			if ($item->parentId != null)
			{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '?expand=' . $linkExpand;
				//$resultString .= '&parentId='.$item->parentId;
				$resultString .= '">';
			}
			else
			{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '?expand='.$linkExpand.'">';
			}
			$resultString .= $this->configuration['icons'] ['overviewexpand'];
                        $resultString .= '</a>&nbsp;';
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modify&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons'] ['folder_closed'];
			$resultString .= '</a>';
		}
		$resultString .= '</td>';
		$resultString .= '<td align="left">';
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= '<b>'.$item->name.'</b>';
		$resultString .= '</a>';
		$resultString .= '</td>';
		$resultString .= '<td align="right">ID:'.$item->itemId.'</td>';
		$resultString .= '</tr></table>';

		/*
		$resultString = '<table border="1" width="100%">';
		$resultString .= '<tr class="'.$class.'"><td>';
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['folder_closed'];
		$resultString .= '</a>';

		
		$resultString .= '<br />';
		$resultString .= '</td>';
		$resultString .= '<td align="right">ID:'.$item->itemId.'</td>';
		$resultString .= '</tr></table>';
		*/
		return $resultString;
		
	}
	
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $identLevel)
	{
		if ($identLevel % 2 == 0)
		{
			$class = 'overviewTreeEven';
		}
		else
		{
			$class = 'overviewTreeOdd';
		}
		// header with two icons and overlib popup
		$resultString = '<table border="0" cellpadding="2" class="'.$class.'" width="100%"><tr class="'.$class.'">';
		$resultString .= '<td width="22" align="left">';
		$resultString .= '<a href="'.$this->configuration['callback'].'?itemId=';
		$resultString .= $item->itemId.'&action=modify" ';
		$resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
		$resultString .= '</td>';
		
		$resultString .= '<td width="22" align="left">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?itemId='.$item->itemId;
		$resultString .= '&parentId='.$item->parentId;
		$resultString .= '&action=delete" ';
		// delete confirmation
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';

		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td>';
		$resultString .= '<td colspan="5">';
		$resultString .= '<a href="'.$this->configuration['callback'].'?itemId='.$item->itemId.'&action=modify" ';
		if ($this->configuration['overlib'])
		{
			$resultString .= $this->overLib ($item->name, $item->description);
		}
		$resultString .= '>';
		$resultString .= $this->stringUtils->truncate ($item->name, 30). '</a>';
		$resultString .= '</td>';
		/*
		$resultString .= '<td><form method="POST">';
		$resultString .= '<input type="hidden" name="action" ';
	        $resultString .= 'value="moveItem" />';	
		$resultString .= '<input type="text" name="itemId" ';
	        $resultString .= 'value="'.$item->parentId.'" />';	
		$resultString .= '<input type="hidden" name="itemId" ';
	        $resultString .= 'value="'.$item->itemId.'" />';	

		$resultString .= '</form></td>';
		*/
		$resultString .= '<td align="right">ID:'.$item->itemId.'</td>';
		
		$resultString .= '</tr><tr class="'.$class.'">';

		$resultString .= '<td colspan="2">&nbsp;</td>';
		$resultString .= '<td colspan="2">'.$this->configuration['dictionary']['priority'.$item->priority].'</td>';
		$resultString .= '<td>';
		if ($item->status != null)
		{
			$resultString .= $item->status;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';
		$resultString .= '<td>'.$this->configuration['dictionary']['complete'].': '.$item->percentComplete.'%</td>';
		$resultString .= '<td>'.$item->startDate.'</td>';
		$resultString .= '<td>';
		if ($item->endDate < date("Y-m-d H:i:s"))
		{
			$resultString .= '<font color="ff0000">';
			$resultString .= $item->endDate;
			$resultString .= '</font>';
		}
		else
		{
			$resultString .= $item->endDate;
		}
		$resultString .= '</td></tr>';
		if ($item->description != null)
		{
			$resultString .= '<tr class="'.$class.'">';
			$resultString .= '<td colspan="2">&nbsp;</td>';
			$resultString .= '<td colspan="6">';
			$resultString .= $item->description;
			$resultString .= '</td></tr>';
		}

		$resultString .= '</table>';
		return $resultString;
	}
	
}
?>
