<?php
/*
 * This file is part of the Booby project.
 * The booby project is located at the following location:
 * http://www.nauta.be/booby/
 *
 * Booby - Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes in the file 'gpl.html' or on the following
 * website: http://www.gnu.org and look for licenses
 *
 * Enjoy :-)
 */
require_once ("base/util/StringUtils.php");
require_once ("base/view/TreeDelegate.php");
/**
 * Used in combination with the Tree class
 *
 * @author Barry Nauta July 2003
 * @package be.nauta.booby.plugins.todos.view
 * @copyright 
 *
 * Copyright (c) 2003 - 2004 Barry Nauta
 *
 * The Booby project is released under the General Public License
 * More detailes on the following
 * website: <code>http://www.gnu.org</code> 
 * and look for licenses
 */
class TodoYahooTreeDelegate extends TreeDelegate 
{
	/**
	 * Default constructor
	 * @param array theIcons the icons used for display
	 * @param string theCallbackURL
	 */
	function TodoYahooTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div><script language="JavaScript" src="base/view/javascript/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>';

		if ($item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		return $resultString;
	}
	
	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';
		
		$resultString .= '<br />';
		return $resultString;
	}
	
	
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString  = '
						 <table border="1" valign="top" width="200" ';
		$resultString .= 'bgcolor="#ffffff"	cellpadding="0" cellspacing="2">';
		
		
		//	Note header: title with link, icons (delete+modify)
		//	and note popup
		$resultString .= '<tr><td class="menu" colspan="2">';
		$resultString .= '<table width="100%" cellpadding="0" cellspacing="0" border="0">';

		// header with two icons and overlib popup
		$resultString .= '<tr bgcolor="#cccccc">';
		$resultString .= '<td>';
		$resultString .= '<table border="0" width="100%">';
		$resultString .= '<tr>';
		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'].'?itemId='.$item->itemId.'&action=modify" ';
		if ($this->configuration['overlib'])
		{
			$resultString .= $this->overLib ($item->name, $item->description);
		}
/*
		$resultString .= 'onmouseover="return overlib(\'';
		$resultString .= $this->stringUtils->urlEncode ($item->description);
		$resultString .= '\', CAPTION, \'';
		$resultString .= $this->stringUtils->urlEncode($item->name).'\');" ';
		$resultString .= ' onmouseout="return nd();">;
*/
		$resultString .= '>';
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->name, 30). '</b></a>';
		$resultString .= '</td><td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'].'?itemId=';
		$resultString .= $item->itemId.'&action=modify" ';
		$resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
		$resultString .= '</td><td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?itemId='.$item->itemId;
		$resultString .= '&parentId='.$item->parentId;
		$resultString .= '&action=delete" ';
		// delete confirmation
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';

		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td></tr></table></td></tr><tr><td bgcolor="f3f3f3">';
		$resultString .= $this->stringUtils->truncate ($item->description, 60);
		$resultString .= '</td></tr>';
		$resultString .= '</table>';
		$resultString .= '</td></tr>';
		// end header
		
		$resultString .= '<tr><td>';
		$resultString .= $this->configuration['dictionary']['priority'];
		$resultString .= '</td><td>';
		$resultString .= $this->configuration['dictionary']['priority'.$item->priority];
		$resultString .= '</td></tr>';
				
		$resultString .= '<tr><td>';
		$resultString .= $this->configuration['dictionary']['status'];
		$resultString .= '</td><td>';
		if ($item->status != null)
		{
			$resultString .= $item->status;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td></tr>';

		$resultString .= '<tr><td>';
		$resultString .= $this->configuration['dictionary']['complete'];
		$resultString .= '</td><td>';
		$resultString .= $item->percentComplete;
		$resultString .= '</td></tr>';

		$resultString .= '<tr><td>';
		$resultString .= $this->configuration['dictionary']['start_date'];
		$resultString .= '</td><td>';
		$resultString .= date ('Y-m-d', strtotime ($item->startDate));
		$resultString .= '</td></tr>';

		$resultString .= '<tr><td>';
		if ($item->endDate < date("Y-m-d H:i:s"))
		{
			$resultString .= '<font color="ff0000">';
			$resultString .= $this->configuration['dictionary']['due_date'];
			$resultString .= '</font>';
			$resultString .= '</td><td>';
			$resultString .= '<font color="ff0000">';
			$resultString .= date ('Y-m-d', strtotime ($item->endDate));
			$resultString .= '</font>';
		}
		else
		{
			$resultString .= $this->configuration['dictionary']['due_date'];
			$resultString .= '</td><td>';
			$resultString .= $item->endDate;
		}
		$resultString .= '</td></tr>';

		$resultString .= '</table>';
	
		$resultString .= '<br />';
		return $resultString;
	}	
}
?>
